@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2005 by Koos Vriezen <koos ! vriezen ? gmail ! com>
+ * Copyright (C) 2005 by Koos Vriezen <koos.vriezen@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,65 +16,55 @@
  * Boston, MA 02110-1301, USA.
  **/
 
-//#include <config.h>
-#include <string.h>
+#include "config-kmplayer.h"
+#include <kdebug.h>
 #include "kmplayer_rss.h"
 #include "kmplayer_atom.h"
 
 using namespace KMPlayer;
 
-KMPLAYER_NO_EXPORT Node *RSS::Rss::childFromTag (const String & tag) {
-    if (!strcmp ((const char *) tag, "channel"))
+KDE_NO_EXPORT Node *RSS::Rss::childFromTag (const QString & tag) {
+    if (!strcmp (tag.latin1 (), "channel"))
         return new RSS::Channel (m_doc);
-    return NULL;
+    return 0L;
 }
 
-void *RSS::Rss::role (RoleType msg, void *content)
-{
-    if (RolePlaylist == msg)
-        return NULL;
-    return Element::role (msg, content);
-}
-
-KMPLAYER_NO_EXPORT Node *RSS::Channel::childFromTag (const String & tag) {
-    const char *ctag = (const char *) tag;
+KDE_NO_EXPORT Node *RSS::Channel::childFromTag (const QString & tag) {
+    const char *ctag = tag.ascii ();
     if (!strcmp (ctag, "item"))
         return new RSS::Item (m_doc);
     else if (!strcmp (ctag, "title"))
-        return new DarkNode (m_doc, tag, id_node_title);
+        return new DarkNode (m_doc, ctag, id_node_title);
     else if (!strncmp (ctag, "itunes", 6) ||
             !strncmp (ctag, "media", 5))
-        return new DarkNode (m_doc, tag, id_node_ignored);
-    return NULL;
+        return new DarkNode (m_doc, ctag, id_node_ignored);
+    return 0L;
 }
 
-KMPLAYER_NO_EXPORT void RSS::Channel::closed () {
+KDE_NO_EXPORT void RSS::Channel::closed () {
     for (Node *c = firstChild (); c; c = c->nextSibling ())
         if (c->id == id_node_title) {
-            title = c->innerText ().stripWhiteSpace ();
+            title = c->innerText ().simplifyWhiteSpace ();
             break;
         }
-    Element::closed ();
+    Title::closed ();
 }
 
-void *RSS::Channel::role (RoleType msg, void *content)
-{
-    if (RolePlaylist == msg)
-        return !title.isEmpty () || //return false if no title and only one
-            previousSibling () || nextSibling () ? (PlaylistRole *) this : NULL;
-    return Element::role (msg, content);
+KDE_NO_EXPORT bool RSS::Channel::expose () const {
+    return !title.isEmpty () || //return false if no title and only one
+        previousSibling () || nextSibling ();
 }
 
-KMPLAYER_NO_EXPORT Node *RSS::Item::childFromTag (const String & tag) {
-    const char *ctag = (const char *) tag;
+KDE_NO_EXPORT Node *RSS::Item::childFromTag (const QString & tag) {
+    const char *ctag = tag.ascii ();
     if (!strcmp (ctag, "enclosure"))
         return new RSS::Enclosure (m_doc);
     else if (!strcmp (ctag, "title"))
-        return new DarkNode (m_doc, tag, id_node_title);
+        return new DarkNode (m_doc, ctag, id_node_title);
     else if (!strcmp (ctag, "description"))
-        return new DarkNode (m_doc, tag, id_node_description);
+        return new DarkNode (m_doc, ctag, id_node_description);
     else if (!strcmp (ctag, "category"))
-        return new DarkNode (m_doc, tag, id_node_category);
+        return new DarkNode (m_doc, ctag, id_node_category);
     else if (!strcmp (ctag, "media:group"))
         return new ATOM::MediaGroup (m_doc);
     else if (!strncmp (ctag, "itunes", 6) ||
@@ -83,19 +73,19 @@ KMPLAYER_NO_EXPORT Node *RSS::Item::childFromTag (const String & tag) {
             !strcmp (ctag, "pubDate") ||
             !strcmp (ctag, "guid") ||
             !strncmp (ctag, "media", 5))
-        return new DarkNode (m_doc, tag, id_node_ignored);
-    return NULL;
+        return new DarkNode (m_doc, ctag, id_node_ignored);
+    return 0L;
 }
 
-KMPLAYER_NO_EXPORT void RSS::Item::closed () {
+KDE_NO_EXPORT void RSS::Item::closed () {
     if (!summary_added) {
         ATOM::MediaGroup *group = NULL;
         Enclosure *enclosure = NULL;
-        String description;
+        QString description;
         for (Node *c = firstChild (); c; c = c->nextSibling ()) {
             switch (c->id) {
                 case id_node_title:
-                    title = c->innerText ().stripWhiteSpace ();
+                    title = c->innerText ().simplifyWhiteSpace ();
                     break;
                 case id_node_enclosure:
                     enclosure = static_cast <Enclosure *> (c);
@@ -108,55 +98,19 @@ KMPLAYER_NO_EXPORT void RSS::Item::closed () {
                     break;
             }
         }
+        if (group)
+            group->addSummary (this, NULL);
         if (enclosure) {
             enclosure->setCaption (title);
-            enclosure->m_description = description;
-            int content_links = 0;
-            if (group) {
-                for (Node *c = group->firstChild (); c; ) {
-                    Node *next = c->nextSibling ();
-                    if (ATOM::id_node_media_content == c->id) {
-                        Mrl *mrl = c->mrl ();
-                        if (mrl && mrl->src == enclosure->src)
-                            group->removeChild (c);
-                        else if (!mrl->src.isEmpty ())
-                            content_links++;
-                    }
-                    c = next;
-                }
-                if (!content_links) {
-                    removeChild (group);
-                    group = NULL;
-                }
-            }
+            enclosure->description = description;
         }
-        if (!group)
-            title.clear ();
         summary_added = true;
     }
-    Element::closed ();
-}
-
-void *RSS::Item::role (RoleType msg, void *content)
-{
-    if (RolePlaylist == msg)
-        return title.isEmpty () ? NULL : (PlaylistRole *) this;
-    return Element::role (msg, content);
-}
-
-String RSS::Item::description () const {
-    for (Node *c = firstChild (); c; c = c->nextSibling ())
-        if (c->id == id_node_description)
-            return c->innerText ();
-    return String ();
-}
-
-String RSS::Enclosure::description () const {
-    return m_description;
+    Title::closed ();
 }
 
 KDE_NO_EXPORT void RSS::Enclosure::activate () {
-    document ()->message (MsgInfoString, &m_description);
+    document ()->message (MsgInfoString, &description);
     Mrl::activate ();
 }
 
@@ -166,6 +120,6 @@ KDE_NO_EXPORT void RSS::Enclosure::deactivate () {
 }
 
 KDE_NO_EXPORT void RSS::Enclosure::closed () {
-    src = getAttribute (Ids::attr_url);
+    src = getAttribute (StringPool::attr_url);
     Mrl::closed ();
 }
