@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
  *
- * Copyright (C) 2005 Koos Vriezen <koos.vriezen@xs4all.nl>
+ * Copyright (C) 2005-2006 Koos Vriezen <koos.vriezen@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,6 +21,8 @@
 #ifndef _KMPLAYER_RSS_H_
 #define _KMPLAYER_RSS_H_
 
+#include <qstring.h>
+
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -39,47 +41,42 @@ const short id_node_ignored = 207;
 /**
  * '<RSS>' tag
  */
-class KMPLAYER_NO_EXPORT Rss : public Element, public PlaylistRole
-{
+class KMPLAYER_NO_EXPORT Rss : public Mrl {
 public:
-    KDE_NO_CDTOR_EXPORT Rss (NodePtr & d) : Element (d, id_node_rss) {}
-    Node *childFromTag (const String & tag);
+    KDE_NO_CDTOR_EXPORT Rss (NodePtr & d) : Mrl (d, id_node_rss) {}
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "rss"; }
-    void *role (RoleType msg, void *content=NULL);
+    bool expose () const { return false; }
 };
 
-class KMPLAYER_NO_EXPORT Channel : public Element, public PlaylistRole
-{
+class KMPLAYER_NO_EXPORT Channel : public Title {
 public:
-    KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Element (d, id_node_channel) {}
-    Node *childFromTag (const String & tag);
+    KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Title (d, id_node_channel) {}
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "channel"; }
+    PlayType playType () { return play_type_none; }
     void closed ();
-    void *role (RoleType msg, void *content=NULL);
+    bool expose () const;
 };
 
-class KMPLAYER_NO_EXPORT Item : public Element, public PlaylistRole {
+class KMPLAYER_NO_EXPORT Item : public Title {
 public:
-    KDE_NO_CDTOR_EXPORT Item (NodePtr & d)
-        : Element (d, id_node_item), summary_added (false) {}
-    Node *childFromTag (const String & tag);
-    String description () const;
+    KDE_NO_CDTOR_EXPORT Item (NodePtr &d)
+        : Title (d, id_node_item), summary_added (false) {}
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "item"; }
     void closed ();
-    void *role (RoleType msg, void *content=NULL);
     bool summary_added;
 };
 
 class KMPLAYER_NO_EXPORT Enclosure : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Enclosure(NodePtr &d) : Mrl(d, id_node_enclosure) {}
-    String description () const;
     KDE_NO_EXPORT const char * nodeName () const { return "enclosure"; }
     void closed ();
     void activate ();
     void deactivate ();
-
-    String m_description;
+    QString description;
 };
 
 } //namespace RSS
