@@ -1,6 +1,6 @@
-/* This file is part of the KMPlayer project
+/* This file is part of the KDE project
  *
- * Copyright (C) 2005-2006 Koos Vriezen <koos.vriezen@gmail.com>
+ * Copyright (C) 2005-2007 Koos Vriezen <koos.vriezen@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,7 +21,9 @@
 #ifndef _KMPLAYER_SMILL_H_
 #define _KMPLAYER_SMILL_H_
 
-#include <vector>
+#include "config-kmplayer.h"
+#include <qstring.h>
+#include <qstringlist.h>
 
 #include "kmplayerplaylist.h"
 #include "surface.h"
@@ -30,10 +32,7 @@ struct TransTypeInfo;
 
 namespace KMPlayer {
 
-class ImageActor;
-class Expression;
-
-typedef std::vector <String> StringList;
+class ImageMedia;
 
 /*
  * Interpretation of sizes
@@ -41,10 +40,9 @@ typedef std::vector <String> StringList;
 class KMPLAYER_NO_EXPORT SizeType {
 public:
     SizeType ();
-    SizeType (const String & s, bool force_perc=false);
+    SizeType (const QString & s, bool force_perc=false);
     void reset ();
-    SizeType & operator = (const String & s);
-    SizeType & operator = (Single d);
+    SizeType & operator = (const QString & s);
     SizeType & operator += (const SizeType & s);
     SizeType & operator -= (const SizeType & s);
     SizeType & operator /= (const int i)
@@ -53,7 +51,7 @@ public:
         { perc_size *= f; abs_size *= f; return *this; }
     Single size (Single relative_to = 100) const;
     bool isSet () const { return isset; }
-    String toString () const;
+    QString toString () const;
 private:
     Single perc_size;
     Single abs_size;
@@ -70,13 +68,13 @@ public:
     KDE_NO_CDTOR_EXPORT ~CalculatedSizer () {}
 
     void resetSizes ();
-    void calcSizes (Node *, CalculatedSizer *region_sz, Single w, Single h,
+    void calcSizes (Node *, Single w, Single h,
             Single & xoff, Single & yoff, Single & w1, Single & h1);
-    bool applyRegPoints (Node *, CalculatedSizer *region_sz, Single w, Single h,
+    bool applyRegPoints (Node *, Single w, Single h,
             Single & xoff, Single & yoff, Single & w1, Single & h1);
     SizeType left, top, width, height, right, bottom;
-    String reg_point, reg_align;
-    bool setSizeParam (const TrieString &name, const String &value);
+    QString reg_point, reg_align;
+    bool setSizeParam (const TrieString &name, const QString &value);
     void move (const SizeType &x, const SizeType &y);
 };
 
@@ -86,7 +84,7 @@ public:
 class KMPLAYER_NO_EXPORT Runtime {
 public:
     enum TimingState {
-        TimingsInit = 0, TimingsInitialized, TimingsDisabled,
+        TimingsInit = 0, TimingsInitialized,
         timings_began, timings_started, TimingsTransIn, timings_paused,
         timings_stopped, timings_freezed
     };
@@ -104,8 +102,6 @@ public:
         DurStart = (int) MsgEventStarted,
         DurEnd = (int) MsgEventStopped,
         DurMedia = (int)MsgMediaFinished,
-        DurStateChanged = (int)MsgStateChanged,
-        DurAccessKey = (int)MsgAccessKey,
         DurTransition,
         DurLastDuration
     };
@@ -122,9 +118,8 @@ public:
     /**
      * Reset all data, called from end() and init()
      */
-    void init ();
     void initialize ();
-    bool parseParam (const TrieString & name, const String & value);
+    bool parseParam (const TrieString & name, const QString & value);
     TimingState state () const { return timingstate; }
     void message (MessageType msg, void *content=NULL);
     void *role (RoleType msg, void *content=NULL);
@@ -134,11 +129,9 @@ public:
     struct DurationItem {
         DurationItem ();
         DurationItem &operator = (const DurationItem &other);
-        bool matches (const Duration dur, const Posting *post);
         void clear();
         Duration durval;
         int offset;
-        VirtualVoid *payload;
         ConnectionLink connection;
         DurationItem *next;
     } durations [(const int) DurTimeLast];
@@ -155,14 +148,13 @@ public:
     TimingState timingstate;
     TimingState unpaused_state;
     int repeat_count;
-    String expr;
     ConnectionList m_StartListeners;        // Element about to be started
     ConnectionList m_StartedListeners;      // Element is started
     ConnectionList m_StoppedListeners;      // Element stopped
-    Command *begin_timer;
-    Command *duration_timer;
-    Command *started_timer;
-    Command *stopped_timer;
+    Posting *begin_timer;
+    Posting *duration_timer;
+    Posting *started_timer;
+    Posting *stopped_timer;
     NodePtrW paused_by;
     unsigned int start_time;
     unsigned int finish_time;
@@ -192,84 +184,30 @@ public:
 /**
  * Translates string to centi-seconds or 'special' high number
  */
-bool parseTime (const String & val, int & dur /*, const String & dateformat*/);
+bool parseTime (const QString & val, int & dur /*,const QString & dateformat*/);
 
 class KMPLAYER_NO_EXPORT SmilTextProperties {
 public:
-    enum Align { AlignInherit, AlignLeft, AlignCenter, AlignRight };
-    enum FontWeight { WeightNormal, WeightBold, WeightInherit };
-    enum Spacing { SpaceDefault, SpacePreserve };
-    enum Style {
-        StyleNormal, StyleItalic, StyleOblique, StyleRevOblique, StyleInherit
-    };
-    enum TextDirection { DirLtr, DirRtl, DirLtro, DirRtlo, DirInherit };
-    enum TextMode { ModeAppend, ModeReplace, ModeInherit };
-    enum TextPlace { PlaceStart, PlaceCenter, PlaceEnd, PlaceInherit };
-    enum TextWrap { Wrap, NoWrap, WrapInherit };
-    enum TextWriting { WritingLrTb, WritingRlTb, WritingTbLr, WritingTbRl };
-
     void init ();
-    bool parseParam (const TrieString &name, const String &value);
+    bool parseParam (const TrieString &name, const QString &value);
     void mask (const SmilTextProperties &props);
 
-    String font_family;
-    String text_style;
+    QString font_family;
     int font_color;
     int background_color;
-    unsigned char text_direction;
-    unsigned char font_style;
-    unsigned char font_weight;
-    unsigned char text_mode;
-    unsigned char text_place;
-    unsigned char text_wrap;
-    unsigned char space;
-    unsigned char text_writing;
-    unsigned char text_align;
-    unsigned char padding;
-    SizeType font_size;
-};
-
-class KMPLAYER_NO_EXPORT SmilColorProperty {
-public:
-    void init ();
-    void setColor (const String &value);
-    void setOpacity (const String &value);
-
-    unsigned int color;
-    int opacity;
-};
-
-class KMPLAYER_NO_EXPORT MediaOpacity {
-public:
-    void init ();
-
-    unsigned short opacity;
-    unsigned short bg_opacity;
-};
-
-class KMPLAYER_NO_EXPORT TransitionModule {
-public:
-    TransitionModule ()
-     : trans_start_time (0),
-       trans_out_timer (NULL),
-       trans_out_active (false) {}
-
-    void init ();
-    void begin (Node *n, Runtime *r);
-    bool handleMessage (Node *n, Runtime *r, Surface *s, MessageType m, void *);
-    void cancelTimer (Node *n);
-    void finish (Node *n);
-
-    NodePtrW trans_in;
-    NodePtrW trans_out;
-    NodePtrW active_trans;
-    unsigned int trans_start_time;
-    unsigned int trans_end_time;
-    Command *trans_out_timer;
-    float trans_gain;
-    ConnectionList m_TransformedIn;        // transIn ready
-    ConnectionLink transition_updater;
-    bool trans_out_active;
+    enum { DirLtr, DirRtl, DirLtro, DirRtlo, DirInherit } text_direction;
+    int font_size;
+    enum Style {
+        StyleNormal, StyleItalic, StyleOblique, StyleRevOblique, StyleInherit
+    } font_style;
+    enum { WeightNormal, WeightBold, WeightInherit } font_weight;
+    enum { ModeAppend, ModeReplace, ModeInherit } text_mode;
+    enum { PlaceStart, PlaceCenter, PlaceEnd, PlaceInherit } text_place;
+    QString text_style;
+    enum { Wrap, NoWrap, WrapInherit } text_wrap;
+    enum { SpaceDefault, SpacePreserve } space;
+    enum { WritingLrTb, WritingRlTb, WritingTbLr, WritingTbRl } text_writing;
+    enum Align { AlignInherit, AlignLeft, AlignCenter, AlignRight } text_align;
 };
 
 //-----------------------------------------------------------------------------
@@ -278,7 +216,6 @@ namespace SMIL {
 
 const short id_node_smil = 100;
 const short id_node_head = 101;
-const short id_node_state = 102;
 const short id_node_layout = 103;
 const short id_node_root_layout = 104;
 const short id_node_region = 105;
@@ -289,17 +226,12 @@ const short id_node_par = 111;
 const short id_node_seq = 112;
 const short id_node_switch = 113;
 const short id_node_excl = 114;
-const short id_node_text = 120;
-const short id_node_ref = 121;
-const short id_node_brush = 122;
-const short id_node_smil_text = 123;
-const short id_node_tev = 124;
-const short id_node_clear = 125;
+const short id_node_img = 120;
+const short id_node_text = 122;
+const short id_node_ref = 123;
+const short id_node_brush = 124;
+const short id_node_smil_text = 125;
 const short id_node_text_styling = 126;
-const short id_node_set_value = 127;
-const short id_node_new_value = 128;
-const short id_node_del_value = 129;
-const short id_node_send = 130;
 const short id_node_set = 132;
 const short id_node_animate = 133;
 const short id_node_animate_color = 134;
@@ -311,40 +243,36 @@ const short id_node_priorityclass = 143;
 const short id_node_div = 144;
 const short id_node_span = 145;
 const short id_node_p = 146;
-const short id_node_br = 147;
 const short id_node_anchor = 150;
 const short id_node_area = 151;
-const short id_node_state_data = 151;
 const short id_node_first = id_node_smil;
 const short id_node_first_timed_mrl = id_node_body;
 const short id_node_last_timed_mrl = id_node_animate_motion;
-const short id_node_first_mediatype = id_node_text;
+const short id_node_first_mediatype = id_node_img;
 const short id_node_last_mediatype = id_node_brush;
 const short id_node_first_group = id_node_body;
 const short id_node_last_group = id_node_excl;
 const short id_node_last = 200; // reserve 100 ids
 
-
 /**
  * '<smil>' tag
  */
 class Smil : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Smil (NodePtr & d) : Mrl (d, id_node_smil) {}
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "smil"; }
     PlayType playType () { return play_type_video; }
     void activate ();
     void deactivate ();
     void closed ();
-    void *role (RoleType msg, void *content=NULL);
+    bool expose () const;
     void message (MessageType msg, void *content=NULL);
     void accept (Visitor *v) { v->visit (this); }
-    void jump (const String & id);
+    void jump (const QString & id);
     static Smil * findSmilNode (Node * node);
 
     NodePtrW layout_node;
-    NodePtrW state_node;
 };
 
 /**
@@ -354,40 +282,11 @@ public:
 class KMPLAYER_NO_EXPORT Head : public Element {
 public:
     KDE_NO_CDTOR_EXPORT Head (NodePtr & d) : Element (d, id_node_head) {}
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "head"; }
     void closed ();
     void message (MessageType msg, void *content=NULL);
-};
-
-/**
- * Defines state, should reside below 'head' element
- */
-class KMPLAYER_NO_EXPORT State : public Element {
-public:
-    enum Where { before, after, child };
-    enum Method { get, put };
-    enum Replace { all, instance, none };
-
-    State (NodePtr & d);
-
-    virtual Node *childFromTag (const String & tag);
-    virtual void closed ();
-    virtual void activate ();
-    virtual void parseParam (const TrieString & name, const String & value);
-    virtual void deactivate ();
-    virtual void message (MessageType msg, void *content=NULL);
-    virtual void *role (RoleType msg, void *content=NULL);
-    KDE_NO_EXPORT virtual const char * nodeName () const { return "state"; }
-
-    void newValue (Node *ref, Where w, const String &name, const String &val);
-    void setValue (Node *ref, const String &value);
-    void delValue (Node *ref);
-    void stateChanged (Node *ref);
-
-    ConnectionList m_StateChangeListeners;        // setValue changed a value
-    PostponePtr postpone_lock;                    // pause while loading src
-    MediaInfo *media_info;
+    bool expose () const;
 };
 
 /**
@@ -396,11 +295,12 @@ public:
 class KMPLAYER_NO_EXPORT Layout : public Element {
 public:
     Layout (NodePtr & d);
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "layout"; }
     void closed ();
     void message (MessageType msg, void *content=NULL);
     void accept (Visitor *v) { v->visit (this); }
+    bool expose () const { return false; }
 
     NodePtrW root_layout;
 };
@@ -413,9 +313,10 @@ public:
     enum ShowBackground { ShowAlways, ShowWhenActive };
 
     ~RegionBase ();
+    virtual bool expose () const { return false; }
     virtual void activate ();
     virtual void deactivate ();
-    virtual void parseParam (const TrieString & name, const String & value);
+    virtual void parseParam (const TrieString & name, const QString & value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
     virtual void accept (Visitor *v) { v->visit (this); }
@@ -430,15 +331,11 @@ public:
     CalculatedSizer sizes;
 
     int z_order;
-    SmilColorProperty background_color;
-    MediaOpacity media_opacity;
-    String background_image;
-    enum BackgroundRepeat {
-        BgRepeat, BgRepeatX, BgRepeatY, BgNoRepeat, BgInherit
-    } bg_repeat;
+    unsigned int background_color;
+    int bg_opacity;
+    QString background_image;
     ShowBackground show_background;
     Fit fit;
-    SmilTextProperties font_props;
     ConnectionList m_AttachedMediaTypes;   // active attached mediatypes
 protected:
     RegionBase (NodePtr & d, short id);
@@ -470,7 +367,7 @@ public:
     ~Region ();
     void deactivate ();
     KDE_NO_EXPORT const char * nodeName () const { return "region"; }
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     void message (MessageType msg, void *content=NULL);
     void *role (RoleType msg, void *content=NULL);
 private:
@@ -483,9 +380,10 @@ private:
 class KMPLAYER_NO_EXPORT RegPoint : public Element {
 public:
     KDE_NO_CDTOR_EXPORT RegPoint (NodePtr & d) : Element(d, id_node_regpoint) {}
-    ~RegPoint () {}
+    KDE_NO_CDTOR_EXPORT ~RegPoint () {}
     KDE_NO_EXPORT const char * nodeName () const { return "regPoint"; }
-    void parseParam (const TrieString & name, const String & value);
+    KDE_NO_EXPORT bool expose () const { return false; }
+    void parseParam (const TrieString & name, const QString & value);
     CalculatedSizer sizes;
 };
 
@@ -527,7 +425,8 @@ public:
     void activate ();
     KDE_NO_EXPORT void accept (Visitor * v) { v->visit (this); }
     KDE_NO_EXPORT const char * nodeName () const { return "transition"; }
-    void parseParam (const TrieString & name, const String & value);
+    void parseParam (const TrieString & name, const QString & value);
+    KDE_NO_EXPORT bool expose () const { return false; }
     bool supported ();
     TransType type;
     TransSubType sub_type;
@@ -544,14 +443,15 @@ public:
 class KMPLAYER_NO_EXPORT GroupBase : public Element {
 public:
     ~GroupBase ();
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     PlayType playType () { return play_type_none; }
-    void parseParam (const TrieString &name, const String &value);
+    void parseParam (const TrieString &name, const QString &value);
     void init ();
     void finish ();
     void activate ();
     void deactivate ();
     void reset ();
+    bool expose () const { return false; }
     void message (MessageType msg, void *content=NULL);
     void *role (RoleType msg, void *content=NULL);
     void setJumpNode (NodePtr);
@@ -610,7 +510,7 @@ public:
     Excl (NodePtr & d);
     ~Excl ();
     KDE_NO_EXPORT const char * nodeName () const { return "excl"; }
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     void begin ();
     void deactivate ();
     void message (MessageType msg, void *content=NULL);
@@ -634,9 +534,9 @@ public:
     KDE_NO_CDTOR_EXPORT PriorityClass (NodePtr &d)
         : Element (d, id_node_priorityclass) {}
     KDE_NO_EXPORT const char * nodeName () const { return "priorityClass"; }
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     void init ();
-    void parseParam (const TrieString &, const String &);
+    void parseParam (const TrieString &, const QString &);
     void message (MessageType msg, void *content=NULL);
     KDE_NO_EXPORT void accept (Visitor * v) { v->visit (this); }
 
@@ -655,7 +555,6 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "switch"; }
     // Condition
     void begin ();
-    void init ();
     void deactivate ();
     void reset ();
     void message (MessageType msg, void *content=NULL);
@@ -670,10 +569,11 @@ class KMPLAYER_NO_EXPORT LinkingBase : public Element {
 public:
     KDE_NO_CDTOR_EXPORT ~LinkingBase () {}
     void deactivate ();
-    void parseParam (const TrieString & name, const String & value);
+    KDE_NO_EXPORT bool expose () const { return false; }
+    void parseParam (const TrieString & name, const QString & value);
     ConnectionLink mediatype_attach;
-    String href;
-    String target;
+    QString href;
+    QString target;
     enum { show_new, show_replace } show;
 protected:
     LinkingBase (NodePtr & d, short id);
@@ -687,22 +587,22 @@ public:
     void message (MessageType msg, void *content=NULL);
     void *role (RoleType msg, void *content=NULL);
     KDE_NO_EXPORT const char * nodeName () const { return "a"; }
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT void accept (Visitor * v) { v->visit (this); }
 };
 
 class KMPLAYER_NO_EXPORT Area : public LinkingBase {
 public:
-    Area (NodePtr & d, const String & tag);
+    Area (NodePtr & d, const QString & tag);
     ~Area ();
     void activate ();
-    KDE_NO_EXPORT const char * nodeName () const { return (const char *) tag; }
+    KDE_NO_EXPORT const char * nodeName () const { return tag.ascii (); }
     KDE_NO_EXPORT void accept (Visitor * v) { v->visit (this); }
-    void parseParam (const TrieString & name, const String & value);
+    void parseParam (const TrieString & name, const QString & value);
     void *role (RoleType msg, void *content=NULL);
     SizeType * coords;
     int nr_coords;
-    const String tag;
+    const QString tag;
     MouseListeners mouse_listeners;
 };
 
@@ -711,11 +611,11 @@ public:
  */
 class KMPLAYER_NO_EXPORT MediaType : public Mrl {
 public:
-    MediaType (NodePtr & d, const String & t, short id);
+    MediaType (NodePtr & d, const QString & t, short id);
     ~MediaType ();
 
-    Node *childFromTag (const String & tag);
-    KDE_NO_EXPORT const char * nodeName () const { return (const char*)m_type; }
+    Node *childFromTag (const QString & tag);
+    KDE_NO_EXPORT const char * nodeName () const { return m_type.latin1 (); }
     virtual void closed ();
     virtual void init ();
     virtual void activate ();
@@ -726,65 +626,82 @@ public:
     virtual void finish ();
     virtual void reset ();
     SRect calculateBounds ();
-    virtual void parseParam (const TrieString & name, const String & value);
+    virtual void parseParam (const TrieString & name, const QString & value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
     virtual void accept (Visitor *v) { v->visit (this); }
+    bool expose () const { return false; }
 
     Surface *surface ();
 
     Runtime *runtime;
     SurfacePtrW sub_surface;
     NodePtrW external_tree; // if src points to playlist, the resolved top node
-    TransitionModule transition;
+    NodePtrW trans_in;
+    NodePtrW trans_out;
+    NodePtrW active_trans;
     NodePtrW region_node;
-    String m_type;
+    QString m_type;
     CalculatedSizer sizes;
     CalculatedSizer *pan_zoom;
     Fit fit;
-    Fit effective_fit;
-    SmilColorProperty background_color;
-    MediaOpacity media_opacity;
+    unsigned int background_color;
+    int opacity;
+    int bg_opacity;
     unsigned int bitrate;
+    unsigned int trans_start_time;
+    unsigned int trans_end_time;
+    float trans_gain;
+    Posting *trans_out_timer;
     enum { sens_opaque, sens_transparent, sens_percentage } sensitivity;
+    bool trans_out_active;
 
 protected:
-    virtual void prefetch ();
     virtual void clipStart ();
     virtual void clipStop ();
 
     MouseListeners mouse_listeners;
     ConnectionList m_MediaAttached;
+    ConnectionList m_TransformedIn;        // transIn ready
+    ConnectionLink region_paint;           // attached region needs painting
     ConnectionLink region_attach;          // attached to region
     ConnectionLink document_postponed;     // pause audio/video accordantly
+    ConnectionLink transition_updater;
     PostponePtr postpone_lock;
 };
 
 class KMPLAYER_NO_EXPORT RefMediaType : public MediaType {
 public:
-    RefMediaType (NodePtr &doc, const String &tag);
-    Node *childFromTag (const String & tag);
-    virtual void activate ();
+    RefMediaType (NodePtr &doc, const QString &tag);
+    Node *childFromTag (const QString & tag);
     virtual void begin ();
     virtual void finish ();
-    virtual PlayType playType ();
     virtual void accept (Visitor *);
-    virtual void message (MessageType msg, void *content=NULL);
-    virtual void *role (RoleType msg, void *content=NULL);
-    virtual void prefetch ();
+    virtual bool expose () const;
+    virtual void parseParam (const TrieString &, const QString &);
     virtual void clipStart ();
 };
 
+class KMPLAYER_NO_EXPORT ImageMediaType : public MediaType {
+public:
+    ImageMediaType (NodePtr & d);
+    Node *childFromTag (const QString & tag);
+    PlayType playType () { return play_type_image; }
+    virtual void activate ();
+    virtual void accept (Visitor *);
+    virtual void parseParam (const TrieString &, const QString &);
+    virtual void message (MessageType msg, void *content=NULL);
+};
+
 class KMPLAYER_NO_EXPORT TextMediaType : public MediaType {
 public:
     TextMediaType (NodePtr & d);
     PlayType playType () { return play_type_info; }
     virtual void init ();
     virtual void accept (Visitor *);
-    virtual void parseParam (const TrieString &, const String &);
-    virtual void prefetch ();
+    virtual void parseParam (const TrieString &, const QString &);
 
-    String font_name;
+    QString font_name;
     int font_size;
     unsigned int font_color;
     enum { align_left, align_center, align_right } halign;
@@ -793,10 +710,9 @@ public:
 class KMPLAYER_NO_EXPORT Brush : public MediaType {
 public:
     Brush (NodePtr & d);
-    virtual void init ();
     virtual void accept (Visitor *);
-    virtual void parseParam (const TrieString &, const String &);
-    SmilColorProperty color;
+    virtual void parseParam (const TrieString &, const QString &);
+    unsigned int color;
 };
 
 class KMPLAYER_NO_EXPORT SmilText : public Element {
@@ -809,24 +725,19 @@ public:
     virtual void finish ();
     virtual void deactivate ();
     virtual void reset ();
+    virtual bool expose () const { return false; }
     KDE_NO_EXPORT const char *nodeName () const { return "smilText"; }
-    Node *childFromTag (const String & tag);
-    virtual void parseParam (const TrieString &name, const String &value);
+    Node *childFromTag (const QString & tag);
+    virtual void parseParam (const TrieString &name, const QString &value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
     virtual void accept (Visitor *v) { v->visit (this); }
 
     Surface *surface ();
-    void updateBounds (bool remove);
 
-    SmilColorProperty background_color;
-    MediaOpacity media_opacity;
-    TransitionModule transition;
     SmilTextProperties props;
     SurfacePtrW text_surface;
     NodePtrW region_node;
-    CalculatedSizer sizes;
-    SSize size;
     ConnectionLink region_attach;
     ConnectionList media_attached;
     MouseListeners mouse_listeners;
@@ -835,106 +746,19 @@ public:
 
 class KMPLAYER_NO_EXPORT TextFlow : public Element {
 public:
-    TextFlow (NodePtr &doc, short id, const String &tag);
+    TextFlow (NodePtr &doc, short id, const QByteArray &tag);
     ~TextFlow ();
 
     virtual void init ();
     virtual void activate ();
-    KDE_NO_EXPORT const char *nodeName () const { return (const char *) tag; }
-    Node *childFromTag (const String &tag);
-    virtual void parseParam (const TrieString &name, const String &value);
+    virtual bool expose () const { return false; }
+    KDE_NO_EXPORT const char *nodeName () const { return tag.data (); }
+    Node *childFromTag (const QString &tag);
+    virtual void parseParam (const TrieString &name, const QString &value);
     virtual void accept (Visitor *v) { v->visit (this); }
 
     SmilTextProperties props;
-    String tag;
-};
-
-class KMPLAYER_NO_EXPORT TemporalMoment : public Element {
-public:
-    TemporalMoment (NodePtr &doc, short id, const String &tag);
-    ~TemporalMoment ();
-    virtual void init ();
-    virtual void activate ();
-    virtual void begin ();
-    virtual void deactivate ();
-    KDE_NO_EXPORT const char *nodeName () const { return (const char *)tag; }
-    Node *childFromTag (const String & tag);
-    virtual void parseParam (const TrieString &name, const String &value);
-    virtual void message (MessageType msg, void *content=NULL);
-    virtual void *role (RoleType msg, void *content=NULL);
-    virtual void accept (Visitor *v) { v->visit (this); }
-
-    Runtime *runtime;
-    String tag;
-};
-
-class KMPLAYER_NO_EXPORT StateValue : public Element {
-public:
-    ~StateValue ();
-
-    virtual void init ();
-    virtual void activate ();
-    virtual void finish ();
-    virtual void deactivate ();
-    virtual void reset ();
-    virtual void parseParam (const TrieString &name, const String &value);
-    virtual void message (MessageType msg, void *content=NULL);
-    virtual void *role (RoleType msg, void *content=NULL);
-protected:
-    StateValue (NodePtr &d, short _id);
-
-    String value;
-    NodePtrW state;
-    Expression *ref;
-    Runtime *runtime;
-};
-
-class KMPLAYER_NO_EXPORT NewValue : public StateValue {
-public:
-    NewValue (NodePtr &d) : StateValue (d, id_node_new_value) {}
-
-    virtual void init ();
-    virtual void begin ();
-    virtual void parseParam (const TrieString &name, const String &value);
-    KDE_NO_EXPORT const char *nodeName () const { return "newvalue"; }
-
-private:
-    String name;
-    SMIL::State::Where where;
-};
-
-class KMPLAYER_NO_EXPORT SetValue : public StateValue {
-public:
-    SetValue (NodePtr &d) : StateValue (d, id_node_set_value) {}
-
-    virtual void begin ();
-    KDE_NO_EXPORT const char *nodeName () const { return "setvalue"; }
-};
-
-class KMPLAYER_NO_EXPORT DelValue : public StateValue {
-public:
-    DelValue (NodePtr &d) : StateValue (d, id_node_del_value) {}
-
-    virtual void begin ();
-    KDE_NO_EXPORT const char *nodeName () const { return "delvalue"; }
-};
-
-class KMPLAYER_NO_EXPORT Send : public StateValue {
-public:
-    Send (NodePtr &d) : StateValue (d, id_node_send), media_info (NULL) {}
-
-    virtual void init ();
-    virtual void begin ();
-    virtual void deactivate ();
-    virtual void parseParam (const TrieString &name, const String &value);
-    virtual void message (MessageType msg, void *content=NULL);
-    KDE_NO_EXPORT const char *nodeName () const { return "send"; }
-
-private:
-    String action;
-    SMIL::State::Replace replace;
-    SMIL::State::Method method;
-    MediaInfo *media_info;
+    QByteArray tag;
 };
 
 class KMPLAYER_NO_EXPORT AnimateGroup : public Element {
@@ -945,18 +769,19 @@ public:
     virtual void finish ();
     virtual void deactivate ();
     virtual void reset ();
-    virtual void parseParam (const TrieString & name, const String & value);
+    virtual bool expose () const { return false; }
+    virtual void parseParam (const TrieString & name, const QString & value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
     Runtime *runtime;
 protected:
-    virtual void restoreModification ();
+    void restoreModification ();
     Node *targetElement ();
     AnimateGroup (NodePtr &d, short _id);
     NodePtrW target_element;
     TrieString changed_attribute;
-    String target_id;
-    String change_to;
+    QString target_id;
+    QString change_to;
     int modification_id;
 };
 
@@ -981,12 +806,12 @@ public:
     virtual void begin ();
     virtual void finish ();
     virtual void deactivate ();
-    virtual void parseParam (const TrieString & name, const String & value);
+    virtual void parseParam (const TrieString & name, const QString & value);
     virtual void message (MessageType msg, void *content=NULL);
     virtual void accept (Visitor *v) { v->visit (this); }
     PlayType playType () { return play_type_none; }
 
-    Command *anim_timer;
+    Posting *anim_timer;
 protected:
     virtual bool timerTick (unsigned int cur_time) = 0;
     virtual void applyStep () = 0;
@@ -996,13 +821,13 @@ protected:
     enum { acc_none, acc_sum } accumulate;
     enum { add_replace, add_sum } additive;
     enum { calc_discrete, calc_linear, calc_paced, calc_spline } calcMode;
-    String change_from;
-    String change_by;
-    StringList values;
+    QString change_from;
+    QString change_by;
+    QStringList values;
     ConnectionLink change_updater;
     float *keytimes;
     Point2D *spline_table;
-    StringList splines;
+    QStringList splines;
     float control_point[4];
     unsigned int keytime_count;
     unsigned int keytime_steps;
@@ -1013,12 +838,11 @@ protected:
 
 class KMPLAYER_NO_EXPORT Animate : public AnimateBase {
 public:
-    Animate (NodePtr &doc);
+    Animate (NodePtr &doc) : AnimateBase (doc, id_node_animate) {}
 
     virtual void init ();
     virtual void begin ();
     virtual void finish ();
-    virtual void deactivate ();
     //virtual void accept (Visitor *v) { v->visit (this); }
     KDE_NO_EXPORT const char * nodeName () const { return "animate"; }
 
@@ -1026,13 +850,10 @@ private:
     virtual bool timerTick (unsigned int cur_time);
     virtual void applyStep ();
 
-    void cleanUp ();
-
-    int num_count;
-    SizeType *begin_;
-    SizeType *cur;
-    SizeType *delta;
-    SizeType *end;
+    SizeType begin_;
+    SizeType cur;
+    SizeType delta;
+    SizeType end;
 };
 
 class KMPLAYER_NO_EXPORT AnimateMotion : public AnimateBase {
@@ -1046,11 +867,9 @@ public:
     KDE_NO_EXPORT const char * nodeName () const { return "animateMotion"; }
 
 private:
-    virtual void restoreModification ();
     virtual bool timerTick (unsigned int cur_time);
     virtual void applyStep ();
 
-    CalculatedSizer old_sizes;
     SizeType begin_x, begin_y;
     SizeType cur_x, cur_y;
     SizeType delta_x, delta_y;
@@ -1096,6 +915,7 @@ public:
     KDE_NO_CDTOR_EXPORT Param (NodePtr & d) : Element (d, id_node_param) {}
     KDE_NO_EXPORT const char * nodeName () const { return "param"; }
     void activate ();
+    bool expose () const { return false; }
 };
 
 } // SMIL namespace
