@@ -16,16 +16,17 @@
  * Boston, MA 02110-1301, USA.
  **/
 
-#include <config.h>
-#include <string.h>
+#include "config-kmplayer.h"
+#include <kdebug.h>
+#include <kurl.h>
 
 #include "kmplayer_xspf.h"
 
 using namespace KMPlayer;
 
 
-KDE_NO_EXPORT Node *XSPF::Playlist::childFromTag (const String & tag) {
-    const char * name = (const char *) tag;
+KDE_NO_EXPORT Node *XSPF::Playlist::childFromTag (const QString & tag) {
+    const char * name = tag.latin1 ();
     if (!strcasecmp (name, "tracklist"))
         return new Tracklist (m_doc);
     else if (!strcasecmp (name, "creator"))
@@ -54,39 +55,32 @@ KDE_NO_EXPORT Node *XSPF::Playlist::childFromTag (const String & tag) {
         return new DarkNode (m_doc, name, id_node_meta);
     else if (!strcasecmp (name, "extension"))
         return new DarkNode (m_doc, name, id_node_extension);
-    return NULL;
+    return 0L;
 }
 
 KDE_NO_EXPORT void XSPF::Playlist::closed () {
     for (Node *e = firstChild (); e; e = e->nextSibling ()) {
         if (e->id == id_node_title)
-            title = e->innerText ().stripWhiteSpace ();
+            title = e->innerText ().simplifyWhiteSpace ();
         else if (e->id == id_node_location)
             src = e->innerText ().stripWhiteSpace ();
     }
     Mrl::closed ();
 }
 
-void *XSPF::Playlist::role (RoleType msg, void *content)
-{
-    if (RolePlaylist == msg)
-        return !title.isEmpty () ? (PlaylistRole *) this : NULL;
-    return Mrl::role (msg, content);
-}
-
 //-----------------------------------------------------------------------------
 
-KDE_NO_EXPORT Node *XSPF::Tracklist::childFromTag (const String & tag) {
-    const char * name = (const char *) tag;
+KDE_NO_EXPORT Node *XSPF::Tracklist::childFromTag (const QString & tag) {
+    const char * name = tag.latin1 ();
     if (!strcasecmp (name, "track"))
         return new XSPF::Track (m_doc);
-    return NULL;
+    return 0L;
 }
 
 //-----------------------------------------------------------------------------
 
-KDE_NO_EXPORT Node *XSPF::Track::childFromTag (const String & tag) {
-    const char * name = (const char *) tag;
+KDE_NO_EXPORT Node *XSPF::Track::childFromTag (const QString & tag) {
+    const char * name = tag.latin1 ();
     if (!strcasecmp (name, "location"))
         return new Location (m_doc);
     else if (!strcasecmp (name, "creator"))
@@ -113,35 +107,44 @@ KDE_NO_EXPORT Node *XSPF::Track::childFromTag (const String & tag) {
         return new DarkNode (m_doc, name, id_node_meta);
     else if (!strcasecmp (name, "extension"))
         return new DarkNode (m_doc, name, id_node_extension);
-    return NULL;
+    return 0L;
 }
 
 KDE_NO_EXPORT void XSPF::Track::closed () {
-    Location *location = NULL;
-    String title;
     for (Node *e = firstChild (); e; e = e->nextSibling ()) {
         switch (e->id) {
             case id_node_title:
-                title = e->innerText ().stripWhiteSpace ();
+                title = e->innerText ();
                 break;
             case id_node_location:
-                location = static_cast <Location *> (e);
+                location = e;
+                src = e->mrl ()->src;
                 break;
         }
     }
-    if (location && !title.isEmpty ())
-        location->setCaption (title);
-    Element::closed ();
+    Mrl::closed ();
 }
 
 KDE_NO_EXPORT void XSPF::Track::activate () {
     for (Node *e = firstChild (); e; e = e->nextSibling ())
         if (e->id == id_node_annotation) {
-            String inf = e->innerText ().stripWhiteSpace ();
+            QString inf = e->innerText ().stripWhiteSpace ();
             document ()->message (MsgInfoString, &inf);
             break;
         }
-    Element::activate ();
+    Mrl::activate ();
+}
+
+KDE_NO_EXPORT Node::PlayType XSPF::Track::playType () {
+    if (location)
+        return location->playType ();
+    return Mrl::playType ();
+}
+
+KDE_NO_EXPORT Mrl * XSPF::Track::linkNode () {
+    if (location)
+        return location->mrl ();
+    return Mrl::linkNode ();
 }
 
 void XSPF::Location::closed () {
