@@ -1,4 +1,4 @@
-/* This file is part of the KMPlayer project
+/* This file is part of the KDE project
  *
  * Copyright (C) 2006 Koos Vriezen <koos.vriezen@gmail.com>
  *
@@ -21,6 +21,8 @@
 #ifndef _KMPLAYER_XSPF_H_
 #define _KMPLAYER_XSPF_H_
 
+#include <qstring.h>
+
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -50,26 +52,30 @@ const short id_node_link = 518;
 class KMPLAYER_NO_EXPORT Playlist : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Playlist (NodePtr & d) : Mrl (d, id_node_playlist) {}
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
-    void *role (RoleType msg, void *content=NULL);
+    bool expose () const { return !title.isEmpty (); }
     void closed ();
 };
 
 class KMPLAYER_NO_EXPORT Tracklist : public Element {
 public:
     KDE_NO_CDTOR_EXPORT Tracklist (NodePtr & d) : Element (d, id_node_tracklist) {}
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "tracklist"; }
+    bool expose () const { return false; }
 };
 
-class KMPLAYER_NO_EXPORT Track : public Element {
+class KMPLAYER_NO_EXPORT Track : public Mrl {
 public:
-    KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Element (d, id_node_track) {}
+    KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Mrl (d, id_node_track) {}
     void closed ();
     void activate ();
+    PlayType playType ();
+    Mrl * linkNode ();
     KDE_NO_EXPORT const char * nodeName () const { return "track"; }
-    Node *childFromTag (const String & tag);
+    Node *childFromTag (const QString & tag);
+    NodePtrW location;
 };
 
 class KMPLAYER_NO_EXPORT Location : public Mrl {
@@ -77,6 +83,7 @@ public:
     KDE_NO_CDTOR_EXPORT Location (NodePtr &d) : Mrl (d, id_node_location) {}
     KDE_NO_EXPORT const char * nodeName () const { return "location"; }
     void closed ();
+    bool expose () const { return false; }
 };
 
 } //namespace XSPF
