@@ -1,6 +1,6 @@
-/* This file is part of the KMPlayer project
+/* This file is part of the KDE project
  *
- * Copyright (C) 2004-2006 Koos Vriezen <koos.vriezen@gmail.com>
+ * Copyright (C) 2004 Koos Vriezen <koos.vriezen@xs4all.nl>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,22 +23,53 @@
 #ifndef _KMPLAYER_PLAYLIST_H_
 #define _KMPLAYER_PLAYLIST_H_
 
-#include <config.h>
+#include "config-kmplayer.h"
 #include <sys/time.h>
 
+#include <qstring.h>
+
+#include "kmplayer_def.h"
 #include "kmplayertypes.h"
 #include "kmplayershared.h"
 
+typedef struct _cairo_surface cairo_surface_t;
+
+class QTextStream;
+class KUrl;
+
 namespace KMPlayer {
 
 class Document;
 class Node;
 class TextNode;
+class Posting;
 class Mrl;
 class ElementPrivate;
 class Visitor;
 class MediaInfo;
-class Process;
+
+template <class T> class KMPLAYER_EXPORT GlobalShared {
+    T **global;
+    int refcount;
+public:
+    GlobalShared (T **glob);
+    virtual ~GlobalShared () {}
+
+    void ref () { refcount++; }
+    void unref();
+};
+
+template <class T>
+inline GlobalShared<T>::GlobalShared (T **glob) : global (glob), refcount (1) {
+    *global = static_cast <T*> (this);
+}
+
+template <class T> inline void GlobalShared<T>::unref() {
+    if (--refcount <= 0) {
+        *global = NULL;
+        delete this;
+    }
+}
 
 /*
  * Base class for objects that will be used as SharedPtr/WeakPtr pointers.
@@ -46,7 +77,7 @@ class Process;
  * \sa: self()
  */
 template <class T>
-class KMPLAYER_NO_EXPORT Item {
+class KMPLAYER_EXPORT Item {
     friend class SharedPtr<T>;
     friend class WeakPtr<T>;
 public:
@@ -104,10 +135,10 @@ private:
  }
 
 /*
- * A double linked list of ListNodeBase<T> nodes
+ * A shareable double linked list of ListNodeBase<T> nodes
  */
 template <class T>
-class KMPLAYER_NO_EXPORT List {
+class KMPLAYER_EXPORT List : public Item <List <T> > {
 public:
     List () {}
     List (typename Item<T>::SharedType f, typename Item<T>::SharedType l)
@@ -117,7 +148,6 @@ public:
     T* first () const { return m_first.ptr (); }
     T* last () const { return m_last.ptr (); }
     void append (T *c);
-    void splice (T *pos, List <T> &lst);
     void insertBefore (T *c, T *b);
     void remove (T *c);
     void clear ();
@@ -125,8 +155,6 @@ public:
     T* item (int i) const;
 
 protected:
-    void removeImpl (T *c);
-
     typename Item<T>::SharedType m_first;
     typename Item<T>::WeakType m_last;
 };
@@ -136,7 +164,7 @@ protected:
  * The linkage is a shared nextSibling and a weak previousSibling.
  */
 template <class T>
-class KMPLAYER_NO_EXPORT ListNodeBase : public Item <T> {
+class KMPLAYER_EXPORT ListNodeBase : public Item <T> {
     friend class List<T>;
 public:
     T* nextSibling () const { return m_next.ptr (); }
@@ -162,7 +190,7 @@ public:
  * The linkage is a shared firstChild and weak parentNode.
  */
 template <class T>
-class KMPLAYER_NO_EXPORT TreeNode : public ListNodeBase <T> {
+class KMPLAYER_EXPORT TreeNode : public ListNodeBase <T> {
 public:
     void insertBefore (T *c, T *b);
     void appendChild (T *c);
@@ -186,20 +214,18 @@ protected:
 /**
  * Attribute having a name/value pair for use with Elements
  */
-class KMPLAYER_NO_EXPORT Attribute : public ListNodeBase <Attribute> {
+class KMPLAYER_EXPORT Attribute : public ListNodeBase <Attribute> {
 public:
     KDE_NO_CDTOR_EXPORT Attribute () {}
-    Attribute (const TrieString &ns, const TrieString &n, const String &v);
+    Attribute (const TrieString & n, const QString & v);
     KDE_NO_CDTOR_EXPORT ~Attribute () {}
-    TrieString ns () const { return m_namespace; }
     TrieString name () const { return m_name; }
-    String value () const { return m_value; }
+    QString value () const { return m_value; }
     void setName (const TrieString &);
-    void setValue (const String &);
+    void setValue (const QString &);
 protected:
-    TrieString m_namespace;
     TrieString m_name;
-    String m_value;
+    QString m_value;
 };
 
 ITEM_AS_POINTER(KMPlayer::Attribute)
@@ -227,14 +253,9 @@ enum MessageType
     MsgEventStarted,
     MsgEventStopped,
     MsgMediaFinished,
-    MsgStateChanged,
-    MsgAccessKey,
     // the above messages are ordered like SMIL timing events
-    MsgMediaPrefetch,
     MsgMediaReady,
-    MsgMediaStarted,
     MsgMediaUpdated,
-    MsgListUpdated,
     MsgEventPostponed,
     MsgSurfaceBoundsUpdate,      // bool parent surface resized
     MsgSurfaceUpdate,
@@ -244,23 +265,19 @@ enum MessageType
     MsgChildReady,
     MsgChildTransformedIn,
     MsgChildFinished,
-    MsgShowMeta,
 
-    MsgInfoString,               // String*
-    MsgBannerString              // String*
+    MsgInfoString                // QString*
 };
 
 enum RoleType
 {
     RoleReady,
-    RoleActorAgent,
+    RoleMediaManager,
     RoleTiming,
     RoleDisplay,
     RoleChildDisplay,    // Mrl*
     RoleSizer,
-    RoleReceivers,
-    RolePlaylist,
-    RoleCaption
+    RoleReceivers
 };
 
 #define MsgUnhandled ((void *) 357L)
@@ -278,17 +295,20 @@ typedef Item<Node>::WeakType NodePtrW;
 typedef Item<Attribute>::SharedType AttributePtr;
 typedef Item<Attribute>::WeakType AttributePtrW;
 typedef List<Node> NodeList;                 // eg. for Node's children
+typedef Item<NodeList>::SharedType NodeListPtr;
+typedef Item<NodeList>::WeakType NodeListPtrW;
+ITEM_AS_POINTER(KMPlayer::NodeList)
 typedef List<Attribute> AttributeList;       // eg. for Element's attributes
+typedef Item<AttributeList>::SharedType AttributeListPtr;
+ITEM_AS_POINTER(KMPlayer::AttributeList)
 typedef ListNode<NodePtrW> NodeRefItem;      // Node for ref Nodes
 ITEM_AS_POINTER(KMPlayer::NodeRefItem)
 typedef ListNode<NodePtr> NodeStoreItem;   // list stores Nodes
-ITEM_AS_POINTER(KMPlayer::NodeStoreItem)
+typedef List<NodeStoreItem> NodeStoreList;
 typedef NodeRefItem::SharedType NodeRefItemPtr;
 typedef NodeRefItem::WeakType NodeRefItemPtrW;
 typedef List<NodeRefItem> NodeRefList;       // ref nodes, eg. event receivers
-typedef List<NodeStoreItem> NodeStoreList;
 
-template <> void List<NodeRefItem>::remove (NodeRefItem *c);
 template <> void TreeNode<Node>::appendChild (Node *c);
 template <> void TreeNode<Node>::insertBefore (Node *c, Node *b);
 template <> void TreeNode<Node>::removeChild (NodePtr c);
@@ -303,26 +323,13 @@ class ConnectionList;
 extern int connection_counter;
 #endif
 
-struct VirtualVoid {
-    virtual ~VirtualVoid () {}
-};
-
-struct KeyLoad : public VirtualVoid {
-    KeyLoad (int ch) : key (ch) {}
-    int key;
-};
-
 struct Connection {
     NodePtrW connectee; // the one that will, when ever, trigger the event
     NodePtrW connecter; // the one that will, when ever, receive the event
-    Connection (Node *invoker, Node*receiver, VirtualVoid *payload);
-    ~Connection () {
-        delete payload;
+    Connection (Node *invoker, Node*receiver);
 #ifdef KMPLAYER_TEST_CONNECTION
-        connection_counter--;
+    ~Connection () { connection_counter--; }
 #endif
-    }
-    VirtualVoid *payload;
     ConnectionList *list;
     Connection **link;
     Connection *prev;
@@ -338,8 +345,7 @@ public:
     ConnectionLink ();
     ~ConnectionLink ();
 
-    bool connect (Node *signaler, MessageType msg, Node *receiver,
-            VirtualVoid *payload=NULL);
+    bool connect (Node *signaler, MessageType msg, Node *receiver);
     void disconnect () const;
     void assign (const ConnectionLink *link) const;
 
@@ -359,7 +365,7 @@ public:
     Connection *link_next;
 public:
     ConnectionList ();
-    ~ConnectionList () KMPLAYER_EXPORT;
+    ~ConnectionList ();
 
     Connection *first () {
         link_next = link_first ? link_first->next : NULL;
@@ -375,11 +381,11 @@ public:
 
 
 struct XMLStringlet {
-    const String str;
-    XMLStringlet (const String & s) : str (s) {}
+    const QString str;
+    XMLStringlet (const QString & s) : str (s) {}
 };
 
-TextStream & operator << (TextStream &out, const XMLStringlet &txt);
+QTextStream & operator << (QTextStream &out, const XMLStringlet &txt);
 
 /*
  * Base class for XML nodes. Provides a w3c's DOM like API
@@ -397,7 +403,7 @@ TextStream & operator << (TextStream &out, const XMLStringlet &txt);
  |-->state_activated<-->state_began<-->state_finished-->state_deactivated-->|
   In scope            begin event    end event         Out scope
  */
-class KMPLAYER_NO_EXPORT Node : public TreeNode <Node> {
+class KMPLAYER_EXPORT Node : public TreeNode <Node> {
     friend class DocumentBuilder;
 public:
     enum State {
@@ -412,13 +418,14 @@ public:
     virtual ~Node ();
     Document * document ();
     virtual Mrl * mrl ();
-    virtual Node *childFromTag (const String & tag);
-    String innerText () const;
-    String innerXML () const;
-    String outerXML (bool inter_doc=true) const;
+    virtual Node *childFromTag (const QString & tag);
+    void characterData (const QString & s);
+    QString innerText () const;
+    QString innerXML () const;
+    QString outerXML () const;
     virtual const char * nodeName () const;
-    virtual String nodeValue () const;
-    virtual void setNodeName (const String &) {}
+    virtual QString nodeValue () const;
+    virtual void setNodeName (const QString &) {}
 
     /**
      * If this is a derived Mrl object and has a SRC attribute
@@ -426,7 +433,16 @@ public:
     virtual PlayType playType ();
     bool isPlayable () { return playType () > play_type_none; }
     virtual bool isElementNode () const { return false; }
-    virtual String description () const;
+    /**
+     * If this node should be visible to the user
+     */
+    virtual bool expose () const;
+    virtual QString caption () const;
+    virtual void setCaption (const QString &t);
+    /**
+     * If this node should be visible to the user
+     */
+    bool isEditable () const { return editable; }
     /**
      * If this node purpose is for storing runtime data only,
      * ie. node doesn't exist in the original document
@@ -494,8 +510,6 @@ public:
     virtual void reset ();
     virtual void clear ();
     void clearChildren ();
-    using TreeNode<Node>::insertBefore;
-    void insertBefore (const String &xml, Node *b);
     void replaceChild (NodePtr _new, NodePtr old);
     /*
      * Get rid of whitespace only text nodes
@@ -503,7 +517,7 @@ public:
     void normalize ();
     KDE_NO_EXPORT bool isDocument () const { return m_doc == m_self; }
 
-    NodeList childNodes () const;
+    KDE_NO_EXPORT NodeListPtr childNodes () const;
     void setState (State nstate);
     /*
      * Open tag is found by parser, attributes are set
@@ -520,6 +534,7 @@ public:
     State state;
     short id;
     bool auxiliary_node : 1;
+    bool editable : 1;
     bool open : 1;
 };
 
@@ -527,26 +542,28 @@ ITEM_AS_POINTER(KMPlayer::Node)
 
 const short id_node_document = 1;
 const short id_node_record_document = 2;
-const short id_node_download_document = 3;
-const short id_node_download = 4;
+const short id_node_grab_document = 3;
 const short id_node_text = 5;
 const short id_node_cdata = 6;
-const short id_node_ref_url = 7;
 
-const short id_node_param = 15;
-const short id_node_svg = 16;
+const short id_node_group_node = 25;
+const short id_node_playlist_document = 26;
+const short id_node_playlist_item = 27;
+const short id_node_param = 28;
+const short id_node_html_object = 29;
+const short id_node_html_embed = 30;
+const short id_node_svg = 31;
 
 /*
  * Element node, XML node that can have attributes
  */
-class KMPLAYER_NO_EXPORT Element : public Node {
+class KMPLAYER_EXPORT Element : public Node {
 public:
     ~Element ();
-    void setAttributes (const AttributeList &attrs);
-    void setAttribute (const TrieString & name, const String & value);
-    String getAttribute (const TrieString & name);
-    KDE_NO_EXPORT AttributeList &attributes () { return m_attributes; }
-    KDE_NO_EXPORT AttributeList attributes () const { return m_attributes; }
+    void setAttributes (AttributeListPtr attrs);
+    void setAttribute (const TrieString & name, const QString & value);
+    QString getAttribute (const TrieString & name);
+    KDE_NO_EXPORT AttributeList *attributes () const { return m_attributes.ptr (); }
     virtual void init ();
     virtual void reset ();
     virtual void clear ();
@@ -557,16 +574,16 @@ public:
      * pass a modification id, that it can use to restore the old value.
      * Param will be auto removed on deactivate
      */
-    void setParam (const TrieString &para, const String &val, int * mod_id=0L);
-    String param (const TrieString & para);
+    void setParam (const TrieString &para, const QString &val, int *mod_id=0L);
+    QString param (const TrieString & para);
     void resetParam (const TrieString & para, int mod_id);
     /**
      * Called from (re)setParam for specialized interpretation of params
      **/
-    virtual void parseParam (const TrieString &, const String &) {}
+    virtual void parseParam (const TrieString &, const QString &) {}
 protected:
     Element (NodePtr & d, short id=0);
-    AttributeList m_attributes;
+    AttributeListPtr m_attributes;
 private:
     ElementPrivate * d;
 };
@@ -584,23 +601,25 @@ inline Node *findChildWithId (const Node *p, const short id) {
     return NULL;
 }
 
-class KMPLAYER_NO_EXPORT PlaylistRole
-{
-public:
-    String caption () const;
-    void setCaption (const String &t);
+class KMPLAYER_EXPORT Title : public Element {
+protected:
+    Title (NodePtr & d, short id=0) : Element (d, id ) {}
 
-    String title;
+public:
+    virtual QString caption () const;
+    virtual void setCaption (const QString &t);
+
+    QString title;
 };
 
 /**
  * Element representing a playable link, like URL to a movie or playlist.
  */
-class KMPLAYER_NO_EXPORT Mrl : public Element, public PlaylistRole {
+class KMPLAYER_EXPORT Mrl : public Title {
 protected:
     Mrl (NodePtr & d, short id=0);
-    Node *childFromTag (const String & tag);
-    void parseParam (const TrieString &, const String &);
+    Node *childFromTag (const QString & tag);
+    void parseParam (const TrieString &, const QString &);
     unsigned int cached_ismrl_version;
     PlayType cached_play_type;
 
@@ -609,8 +628,12 @@ public:
 
     ~Mrl ();
     PlayType playType ();
+    /*
+     * The original node (or this) having the URL, needed for playlist expansion
+     */
+    virtual Mrl * linkNode ();
     virtual Mrl * mrl ();
-    String absolutePath ();
+    QString absolutePath ();
 
     virtual void activate ();
     virtual void begin ();
@@ -620,8 +643,7 @@ public:
     virtual void message (MessageType msg, void *content=NULL);
     virtual void *role (RoleType msg, void *content=NULL);
 
-    static unsigned int parseTimeString (const String &s);
-    static String *parsePanZoomString (const String &pz, String *coord);
+    static unsigned int parseTimeString (const QString &s);
 
     /**
      * If this Mrl is top node of external document, opener has the
@@ -629,33 +651,23 @@ public:
      */
     NodePtrW opener; //if this node is top node of external document,
     MediaInfo *media_info;
-    String src;
-    String mimetype;
+    QString src;
+    QString mimetype;
     SSize size;
     float aspect;
     int repeat;
-    unsigned int clip_begin;
     unsigned char view_mode;
     bool resolved;
     bool bookmarkable;
-    bool audio_only;
-    bool has_played;
-};
-
-class KMPLAYER_NO_EXPORT MrlBackEndNotify
-{
-public:
-    virtual Mrl *sourceMrl () = 0;
-    virtual void referenceMrl (const String &url) = 0;
-    virtual void infoMessage (const String &msg) = 0;
-    virtual void readyToPlay (Process *process) = 0;
+    bool access_granted;
 };
 
 /**
  * Document listener interface
  */
-class KMPLAYER_NO_EXPORT PlayListNotify {
+class KMPLAYER_EXPORT PlayListNotify {
 public:
+    virtual ~PlayListNotify() { }
     /**
      * Element has activated or deactivated notification
      */
@@ -671,38 +683,23 @@ public:
     /**
      * Request to open url with mimetype
      */
-    virtual void openUrl (const URL &, const String &tgt, const String &srv)=0;
+    virtual void openUrl (const KUrl &, const QString &t, const QString &srv)=0;
     /**
      * Dis/Enable repaint updaters
      */
     virtual void enableRepaintUpdaters (bool enable, unsigned int off_time)=0;
 };
 
-struct KMPLAYER_NO_EXPORT Command {
-    virtual void apply (struct timeval &timeout) = 0;
-    virtual bool postponable () const = 0;
-    virtual int delay () const = 0;
-    virtual void removed () = 0;
-};
-
 /*
  *  A generic type for posting messages
  **/
-class KMPLAYER_NO_EXPORT Posting : public Command {
+class KMPLAYER_EXPORT Posting {
 public:
-    KDE_NO_CDTOR_EXPORT Posting (Node *n, Node *tgt, MessageType msg, VirtualVoid *p=NULL)
-        : source (n), target (tgt), message (msg), payload (p) {}
+    KDE_NO_CDTOR_EXPORT Posting (Node *n, MessageType msg)
+        : source (n), message (msg) {}
     KDE_NO_CDTOR_EXPORT virtual ~Posting () {}
-
-    virtual void apply (struct timeval &timeout);
-    virtual bool postponable () const;
-    virtual int delay () const;
-    virtual void removed ();
-
     NodePtrW source;
-    NodePtrW target;
     MessageType message;
-    VirtualVoid *payload;
 };
 
 /**
@@ -710,11 +707,7 @@ public:
  */
 class KMPLAYER_NO_EXPORT TimerPosting : public Posting {
 public:
-    TimerPosting (Node *t, int ms, unsigned eid=0);
-
-    virtual void apply (struct timeval &timeout);
-    virtual int delay () const;
-
+    TimerPosting (int ms, unsigned eid=0);
     unsigned event_id;
     int milli_sec;
     bool interval; // set to 'true' in 'Node::message()' to make it repeat
@@ -752,41 +745,42 @@ public:
 typedef SharedPtr <Postpone> PostponePtr;
 typedef WeakPtr <Postpone> PostponePtrW;
 
-struct KMPLAYER_NO_EXPORT CommandData {
-    CommandData (Command *e, CommandData *n);
-    ~CommandData ();
+struct KMPLAYER_NO_EXPORT EventData {
+    EventData (Node *t, Posting *e, EventData *n);
+    ~EventData ();
 
-    Command *event;
+    NodePtrW target;
+    Posting *event;
     struct timeval timeout;
 
-    CommandData *next;
+    EventData *next;
 };
 
 /**
  * The root of the DOM tree
  */
-class KMPLAYER_NO_EXPORT Document : public Mrl {
+class KMPLAYER_EXPORT Document : public Mrl {
     friend class Postpone;
 public:
-    Document (const String &, PlayListNotify * notify = 0L);
+    Document (const QString &, PlayListNotify * notify = 0L);
     ~Document ();
-    Node *getElementById (const String & id);
-    Node *getElementById (Node *start, const String & id, bool inter_doc);
+    Node *getElementById (const QString & id);
+    Node *getElementById (Node *start, const QString & id, bool inter_doc);
     /** All nodes have shared pointers to Document,
      * so explicitly dispose it (calls clear and set m_doc to 0L)
      * */
     void dispose ();
-    virtual Node *childFromTag (const String & tag);
+    virtual Node *childFromTag (const QString & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "document"; }
     virtual void activate ();
     virtual void defer ();
     virtual void undefer ();
     virtual void reset ();
 
-    Command *post (Command *event);
-    void cancelPosting (Command *event);
-    void pausePosting (Command *e);
-    void unpausePosting (Command *e, int ms);
+    Posting *post (Node *n, Posting *event);
+    void cancelPosting (Posting *event);
+    void pausePosting (Posting *e);
+    void unpausePosting (Posting *e, int ms);
 
     void timeOfDay (struct timeval &);
     PostponePtr postpone ();
@@ -801,23 +795,22 @@ public:
      */
     virtual void *role (RoleType msg, void *content=NULL);
 
-    void insertPosting (Command *e, const struct timeval &tv);
-
     PlayListNotify *notify_listener;
     unsigned int m_tree_version;
     unsigned int last_event_time;
 private:
     void proceed (const struct timeval & postponed_time);
+    void insertPosting (Node *n, Posting *e, const struct timeval &tv);
     void setNextTimeout (const struct timeval &now);
 
     PostponePtrW postpone_ref;
     PostponePtr postpone_lock;
     ConnectionList m_PostponedListeners;
-    CommandData *event_queue;
-    CommandData *paused_queue;
-    CommandData *cur_event;
+    EventData *event_queue;
+    EventData *paused_queue;
+    EventData *cur_event;
+    int cur_timeout;
     struct timeval first_event_time;
-    int cur_time_interval;
 };
 
 namespace SMIL {
@@ -830,15 +823,13 @@ namespace SMIL {
     class Excl;
     class Transition;
     class AnimateBase;
-    class Animate;
-    class AnimateMotion;
     class MediaType;
+    class ImageMediaType;
     class TextMediaType;
     class RefMediaType;
     class Brush;
     class SmilText;
     class TextFlow;
-    class TemporalMoment;
     class PriorityClass;
     class Anchor;
     class Area;
@@ -861,7 +852,6 @@ public:
     virtual void visit (Node *) {}
     virtual void visit (TextNode *);
     virtual void visit (Element *);
-#ifdef KMPLAYER_XML_FORMATS
     virtual void visit (SMIL::Smil *) {}
     virtual void visit (SMIL::Layout *);
     virtual void visit (SMIL::RegionBase *);
@@ -873,12 +863,12 @@ public:
     virtual void visit (SMIL::AnimateBase *);
     virtual void visit (SMIL::PriorityClass *);
     virtual void visit (SMIL::MediaType *);
+    virtual void visit (SMIL::ImageMediaType *);
     virtual void visit (SMIL::TextMediaType *);
     virtual void visit (SMIL::RefMediaType *);
     virtual void visit (SMIL::Brush *);
     virtual void visit (SMIL::SmilText *);
     virtual void visit (SMIL::TextFlow *);
-    virtual void visit (SMIL::TemporalMoment *);
     virtual void visit (SMIL::Anchor *);
     virtual void visit (SMIL::Area *);
     virtual void visit (RP::Imfl *) {}
@@ -889,31 +879,31 @@ public:
     virtual void visit (RP::Wipe *) {}
     virtual void visit (RP::ViewChange *) {}
     virtual void visit (RP::Animate *) {}
-#endif
 };
 
 /**
  * Represents XML text, like "some text" in '<foo>some text</foo>'
  */
-class KMPLAYER_NO_EXPORT TextNode : public Node {
+class KMPLAYER_EXPORT TextNode : public Node {
 public:
-    TextNode (NodePtr & d, const String & s, short _id = id_node_text);
+    TextNode (NodePtr & d, const QString & s, short _id = id_node_text);
     KDE_NO_CDTOR_EXPORT ~TextNode () {}
-    void appendText (const String & s);
-    void setText (const String & txt) { text = txt; }
-    void accept (Visitor *v) { v->visit (this); }
+    void appendText (const QString & s);
+    void setText (const QString & txt) { text = txt; }
     const char * nodeName () const { return "#text"; }
-    String nodeValue () const;
+    void accept (Visitor *v) { v->visit (this); }
+    QString nodeValue () const;
+    bool expose () const;
 protected:
-    String text;
+    QString text;
 };
 
 /**
  * Represents cdata sections, like "some text" in '<![CDATA[some text]]>'
  */
-class KMPLAYER_NO_EXPORT CData : public TextNode {
+class KMPLAYER_EXPORT CData : public TextNode {
 public:
-    CData (NodePtr & d, const String & s);
+    CData (NodePtr & d, const QString & s);
     KDE_NO_CDTOR_EXPORT ~CData () {}
     const char * nodeName () const { return "#cdata"; }
 };
@@ -921,14 +911,15 @@ public:
 /**
  * Unrecognized tag by parent element or just some auxiliary node
  */
-class DarkNode : public Element {
+class KMPLAYER_EXPORT DarkNode : public Element {
 public:
-    DarkNode (NodePtr & d, const String & n, short id=0);
+    DarkNode (NodePtr & d, const QByteArray &n, short id=0);
     KDE_NO_CDTOR_EXPORT ~DarkNode () {}
-    const char * nodeName () const { return (const char *) name; }
-    Node *childFromTag (const String & tag);
+    const char * nodeName () const { return name.data (); }
+    Node *childFromTag (const QString & tag);
+    virtual bool expose () const;
 protected:
-    String name;
+    QByteArray name;
 };
 
 //-----------------------------------------------------------------------------
@@ -936,9 +927,9 @@ protected:
 /**
  * just some url, can get a SMIL, RSS, or ASX childtree
  */
-class KMPLAYER_NO_EXPORT GenericURL : public Mrl {
+class KMPLAYER_EXPORT GenericURL : public Mrl {
 public:
-    GenericURL(NodePtr &d, const String &s, const String &n=String());
+    GenericURL(NodePtr &d, const QString &s, const QString &n=QString ());
     KDE_NO_EXPORT const char * nodeName () const { return "url"; }
     void closed ();
 };
@@ -946,24 +937,19 @@ public:
 /**
  * Non url mrl
  */
-class KMPLAYER_NO_EXPORT GenericMrl : public Mrl {
+class KMPLAYER_EXPORT GenericMrl : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT GenericMrl (NodePtr & d) : Mrl (d), node_name ("mrl") {}
-    GenericMrl(NodePtr &d, const String &s,
-            const String & nm = String(), const String &tag = String ("mrl"));
-    KDE_NO_EXPORT const char * nodeName () const
-        { return (const char *) node_name; }
+    GenericMrl(NodePtr &d, const QString &s, const QString &name=QString (), const QByteArray &tag=QByteArray ("mrl"));
+    KDE_NO_EXPORT const char * nodeName () const { return node_name.data (); }
     void closed ();
-    void *role (RoleType msg, void *content=NULL);
-    /**
-     * Will return false if this document has child nodes
-     */
-    String node_name;
+    bool expose () const;
+    QByteArray node_name;
 };
 
-KMPLAYER_NO_EXPORT
-void readXML (NodePtr root, TextStream & in, const String & firstline, bool set_opener=true);
-KMPLAYER_NO_EXPORT Node * fromXMLDocumentTag (NodePtr & d, const String & tag);
+KMPLAYER_EXPORT
+void readXML (NodePtr root, QTextStream & in, const QString & firstline, bool set_opener=true);
+KMPLAYER_EXPORT Node * fromXMLDocumentTag (NodePtr & d, const QString & tag);
 
 template <class T>
 inline Item<T>::Item () : m_self (static_cast <T*> (this), true) {}
@@ -979,26 +965,6 @@ template <class T> inline void List<T>::append (T *c) {
     }
 }
 
-template <class T> inline void List<T>::splice (T *pos, List <T> &lst) {
-    if (lst.m_first) {
-        if (!pos) {
-            if (!m_first)
-                m_first = lst.m_first;
-            else
-                m_last->m_next = lst.m_first;
-            m_last = lst.m_last;
-        } else {
-            lst.m_last->m_next = pos;
-            if (!pos->m_prev) // pos must be first
-                m_first = lst.m_first;
-            else
-                pos->m_prev->m_next = lst.m_first;
-        }
-        lst.m_first = NULL;
-        lst.m_last = NULL;
-    }
-}
-
 template <class T> inline void List<T>::insertBefore (T *c, T *b) {
     if (!b) {
         append (c);
@@ -1015,7 +981,7 @@ template <class T> inline void List<T>::insertBefore (T *c, T *b) {
     }
 }
 
-template <class T> inline void List<T>::removeImpl (T *c) {
+template <class T> inline void List<T>::remove (T *c) {
     typename Item<T>::SharedType s = c->m_self;
     if (c->m_prev)
         c->m_prev->m_next = c->m_next;
@@ -1030,10 +996,6 @@ template <class T> inline void List<T>::removeImpl (T *c) {
     c->m_prev = 0L;
 }
 
-template <class T> inline void List<T>::remove (T *c) {
-    removeImpl (c);
-}
-
 template <class T> inline unsigned int List<T>::length () const {
     unsigned int count = 0;
     for (T *t = m_first.ptr (); t; t = t->nextSibling ())
@@ -1099,8 +1061,8 @@ inline void TreeNode<T>::removeChildImpl (typename Item<T>::SharedType c) {
     c->m_parent = 0L;
 }
 
-inline KDE_NO_EXPORT NodeList Node::childNodes () const {
-    return NodeList (m_first_child, m_last_child);
+inline KDE_NO_EXPORT NodeListPtr Node::childNodes () const {
+    return new NodeList (m_first_child, m_last_child);
 }
 
 }  // KMPlayer namespace
