@@ -18,25 +18,33 @@
 
 #include <stdio.h>
 
-#include <config.h>
+#include "config-kmplayer.h"
 // include files for Qt
 #include <qapplication.h>
 #include <qclipboard.h>
-#include <qpopupmenu.h>
+#include <QMenu>
 #include <qdrawutil.h>
 #include <qpainter.h>
 #include <qiconset.h>
 #include <qpixmap.h>
-#include <qheader.h>
+#include <Q3Header>
+#include <QDropEvent>
 #include <qstyle.h>
 #include <qtimer.h>
+#include <Q3DragObject>
+#include <QDropEvent>
+#include <Q3TextDrag>
+#include <QPalette>
+#include <qregexp.h>
 
 #include <kiconloader.h>
+#include <kstandardaction.h>
 #include <kfinddialog.h>
-#include <kurldrag.h>
+#include <kfind.h>
 #include <kaction.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <KActionCollection>
 
 #include "playlistview.h"
 #include "kmplayerview.h"
@@ -49,11 +57,12 @@ using namespace KMPlayer;
 namespace KMPlayer {
 
     KDE_NO_EXPORT bool isDragValid (QDropEvent * de) {
-        if (KURLDrag::canDecode (de))
+        KUrl::List uriList = KUrl::List::fromMimeData (de->mimeData ());
+        if (!uriList.isEmpty ())
             return true;
-        if (QTextDrag::canDecode (de)) {
+        if (Q3TextDrag::canDecode (de)) {
             QString text;
-            if (QTextDrag::decode (de, text) && KURL (text).isValid ())
+            if (Q3TextDrag::decode (de, text) && KURL (text).isValid ())
                 return true;
         }
         return false;
@@ -62,32 +71,32 @@ namespace KMPlayer {
 
 //-----------------------------------------------------------------------------
 
-KDE_NO_CDTOR_EXPORT PlayListItem::PlayListItem (QListViewItem *p, const NodePtr & e, PlayListView * lv) : QListViewItem (p), node (e), listview (lv) {}
+KDE_NO_CDTOR_EXPORT PlayListItem::PlayListItem (Q3ListViewItem *p, const NodePtr & e, PlayListView * lv) : Q3ListViewItem (p), node (e), listview (lv) {}
 
-KDE_NO_CDTOR_EXPORT PlayListItem::PlayListItem (QListViewItem *p, const AttributePtr & a, PlayListView * lv) : QListViewItem (p), m_attr (a), listview (lv) {}
+KDE_NO_CDTOR_EXPORT PlayListItem::PlayListItem (Q3ListViewItem *p, const AttributePtr & a, PlayListView * lv) : Q3ListViewItem (p), m_attr (a), listview (lv) {}
 
 KDE_NO_CDTOR_EXPORT
-PlayListItem::PlayListItem (PlayListView *v, const NodePtr &e, QListViewItem *b)
-  : QListViewItem (v, b), node (e), listview (v) {}
+PlayListItem::PlayListItem (PlayListView *v, const NodePtr &e, Q3ListViewItem *b)
+  : Q3ListViewItem (v, b), node (e), listview (v) {}
 
 KDE_NO_CDTOR_EXPORT void PlayListItem::paintCell (QPainter * p, const QColorGroup & cg, int column, int width, int align) {
     if (node && node->state == Node::state_began) {
         QColorGroup mycg (cg);
         mycg.setColor (QColorGroup::Foreground, listview->activeColor ());
         mycg.setColor (QColorGroup::Text, listview->activeColor ());
-        QListViewItem::paintCell (p, mycg, column, width, align);
+        Q3ListViewItem::paintCell (p, mycg, column, width, align);
     } else
-        QListViewItem::paintCell (p, cg, column, width, align);
+        Q3ListViewItem::paintCell (p, cg, column, width, align);
 }
 
 KDE_NO_CDTOR_EXPORT void PlayListItem::paintBranches (QPainter * p, const QColorGroup &, int w, int, int h) {
-    p->fillRect (0, 0, w, h, listview->paletteBackgroundColor());
+    p->fillRect (0, 0, w, h, listview->palette ().color (QPalette::Background));
 }
 
 //-----------------------------------------------------------------------------
 
 KDE_NO_CDTOR_EXPORT
-RootPlayListItem::RootPlayListItem (int _id, PlayListView *v, const NodePtr & e, QListViewItem * before, int flgs)
+RootPlayListItem::RootPlayListItem (int _id, PlayListView *v, const NodePtr & e, Q3ListViewItem * before, int flgs)
   : PlayListItem (v, e, before),
     id (_id),
     flags (flgs),
@@ -96,25 +105,27 @@ RootPlayListItem::RootPlayListItem (int _id, PlayListView *v, const NodePtr & e,
 
 KDE_NO_CDTOR_EXPORT void RootPlayListItem::paintCell (QPainter * p, const QColorGroup & cg, int column, int width, int align) {
     QColorGroup mycg (cg);
-    mycg.setColor (QColorGroup::Base, listview->topLevelWidget()->paletteBackgroundColor());
+    mycg.setColor (QColorGroup::Base,
+            listview->topLevelWidget()->palette ().color (QPalette::Background));
     mycg.setColor (QColorGroup::Highlight, mycg.base ());
-    mycg.setColor (QColorGroup::Text, listview->topLevelWidget()->paletteForegroundColor());
+    mycg.setColor (QColorGroup::Text,
+            listview->topLevelWidget()->palette ().color (QPalette::Foreground));
     mycg.setColor (QColorGroup::HighlightedText, mycg.text ());
-    QListViewItem::paintCell (p, mycg, column, width, align);
+    Q3ListViewItem::paintCell (p, mycg, column, width, align);
     qDrawShadeRect (p, 0, 0, width -1, height () -1, mycg, !isOpen ());
 }
 
 //-----------------------------------------------------------------------------
 
 KDE_NO_CDTOR_EXPORT PlayListView::PlayListView (QWidget * parent, View * view, KActionCollection * ac)
- : KListView (parent, "kde_kmplayer_playlist"),
+ : //K3ListView (parent),
    m_view (view),
    m_find_dialog (0L),
    m_active_color (30, 0, 255),
    last_id (0),
    last_drag_tree_id (0),
    m_ignore_expanded (false) {
-    addColumn (QString::null);
+    addColumn (QString ());
     header()->hide ();
     //setRootIsDecorated (true);
     setSorting (-1);
@@ -122,75 +133,78 @@ KDE_NO_CDTOR_EXPORT PlayListView::PlayListView (QWidget * parent, View * view, K
     setDropVisualizer (true);
     setItemsRenameable (true);
     setItemMargin (2);
-    m_itemmenu = new QPopupMenu (this);
-    folder_pix = KGlobal::iconLoader ()->loadIcon (QString ("folder"), KIcon::Small);
-    auxiliary_pix = KGlobal::iconLoader ()->loadIcon (QString ("folder_grey"), KIcon::Small);
-    video_pix = KGlobal::iconLoader ()->loadIcon (QString ("video"), KIcon::Small);
-    info_pix = KGlobal::iconLoader ()->loadIcon (QString ("messagebox_info"), KIcon::Small);
-    img_pix = KGlobal::iconLoader ()->loadIcon (QString ("colorize"), KIcon::Small);
-    unknown_pix = KGlobal::iconLoader ()->loadIcon (QString ("unknown"), KIcon::Small);
-    menu_pix = KGlobal::iconLoader ()->loadIcon (QString ("player_playlist"), KIcon::Small);
-    config_pix = KGlobal::iconLoader ()->loadIcon (QString ("configure"), KIcon::Small);
-    url_pix = KGlobal::iconLoader ()->loadIcon (QString ("www"), KIcon::Small);
-    m_find = KStdAction::find (this, SLOT (slotFind ()), ac, "find");
-    m_find_next = KStdAction::findNext (this, SLOT(slotFindNext()), ac, "next");
+    QPalette palette;
+    palette.setColor (foregroundRole(), QColor (0, 0, 0));
+    palette.setColor (backgroundRole(), QColor (0xB2, 0xB2, 0xB2));
+    setPalette (palette);
+    m_itemmenu = new QMenu (this);
+    folder_pix = KIconLoader::global ()->loadIcon (QString ("folder"), KIconLoader::Small);
+    auxiliary_pix = KIconLoader::global ()->loadIcon (QString ("folder-grey"), KIconLoader::Small);
+    video_pix = KIconLoader::global ()->loadIcon (QString ("video-x-generic"), KIconLoader::Small);
+    info_pix = KIconLoader::global ()->loadIcon (QString ("dialog-info"), KIconLoader::Small);
+    img_pix = KIconLoader::global ()->loadIcon (QString ("image-png"), KIconLoader::Small);
+    unknown_pix = KIconLoader::global ()->loadIcon (QString ("unknown"), KIconLoader::Small);
+    menu_pix = KIconLoader::global ()->loadIcon (QString ("view-media-playlist"), KIconLoader::Small);
+    config_pix = KIconLoader::global ()->loadIcon (QString ("configure"), KIconLoader::Small);
+    url_pix = KIconLoader::global ()->loadIcon (QString ("internet-web-browser"), KIconLoader::Small);
+    m_find = KStandardAction::find (this, SLOT (slotFind ()), this);
+    m_find_next = KStandardAction::findNext (this, SLOT(slotFindNext()), this);
     m_find_next->setEnabled (false);
-    connect (this, SIGNAL (contextMenuRequested (QListViewItem *, const QPoint &, int)), this, SLOT (contextMenuItem (QListViewItem *, const QPoint &, int)));
-    connect (this, SIGNAL (expanded (QListViewItem *)),
-             this, SLOT (itemExpanded (QListViewItem *)));
-    connect (this, SIGNAL (dropped (QDropEvent *, QListViewItem *)),
-             this, SLOT (itemDropped (QDropEvent *, QListViewItem *)));
-    connect (this, SIGNAL (itemRenamed (QListViewItem *)),
-             this, SLOT (itemIsRenamed (QListViewItem *)));
-    connect (this, SIGNAL (selectionChanged (QListViewItem *)),
-             this, SLOT (itemIsSelected (QListViewItem *)));
+    connect (this, SIGNAL (contextMenuRequested (Q3ListViewItem *, const QPoint &, int)), this, SLOT (contextMenuItem (Q3ListViewItem *, const QPoint &, int)));
+    connect (this, SIGNAL (expanded (Q3ListViewItem *)),
+             this, SLOT (itemExpanded (Q3ListViewItem *)));
+    connect (this, SIGNAL (dropped (QDropEvent *, Q3ListViewItem *)),
+             this, SLOT (itemDropped (QDropEvent *, Q3ListViewItem *)));
+    connect (this, SIGNAL (itemRenamed (Q3ListViewItem *)),
+             this, SLOT (itemIsRenamed (Q3ListViewItem *)));
+    connect (this, SIGNAL (selectionChanged (Q3ListViewItem *)),
+             this, SLOT (itemIsSelected (Q3ListViewItem *)));
 }
 
 KDE_NO_CDTOR_EXPORT PlayListView::~PlayListView () {
 }
 
 int PlayListView::addTree (NodePtr root, const QString & source, const QString & icon, int flags) {
-    //kdDebug () << "addTree " << source << " " << root->mrl()->src << endl;
+    //kDebug () << "addTree " << source << " " << root->mrl()->src;
     RootPlayListItem * ritem = new RootPlayListItem (++last_id, this, root, lastChild(), flags);
     ritem->source = source;
     ritem->icon = icon;
     ritem->setPixmap (0, !ritem->icon.isEmpty ()
-            ? KGlobal::iconLoader ()->loadIcon (ritem->icon, KIcon::Small)
+            ? KIconLoader::global ()->loadIcon (ritem->icon, KIconLoader::Small)
             : url_pix);
     updateTree (ritem, 0L, false);
     return last_id;
 }
 
 KDE_NO_EXPORT PlayListItem * PlayListView::populate
-(NodePtr e, NodePtr focus, RootPlayListItem *root, PlayListItem * pitem, PlayListItem ** curitem) {
+(Node *e, Node *focus, RootPlayListItem *root, PlayListItem * pitem, PlayListItem ** curitem) {
     root->have_dark_nodes |= !e->expose ();
     if (pitem && !root->show_all_nodes && !e->expose ()) {
-        for (NodePtr c = e->lastChild (); c; c = c->previousSibling ())
+        for (Node *c = e->lastChild (); c; c = c->previousSibling ())
             populate (c, focus, root, pitem, curitem);
         return pitem;
     }
     PlayListItem * item = pitem ? new PlayListItem (pitem, e, this) : root;
     Mrl * mrl = e->mrl ();
-    QString text (e->nodeName());
-    if (mrl && !root->show_all_nodes) {
-        if (mrl->pretty_name.isEmpty ()) {
+    QString text (e->caption ());
+    if (text.isEmpty ()) {
+        text = id_node_text == e->id ? e->nodeValue () : e->nodeName ();
+        if (mrl && !root->show_all_nodes) {
             if (!mrl->src.isEmpty())
-                text = KURL(mrl->src).prettyURL (0, KURL::StripFileProtocol);
+                text = KUrl (mrl->src).pathOrUrl ();
             else if (e->isDocument ())
                 text = e->hasChildNodes () ? i18n ("unnamed") : i18n ("none");
-        } else
-            text = mrl->pretty_name;
-    } else if (e->id == id_node_text)
-        text = e->nodeValue ();
+        }
+    }
     item->setText(0, text);
     if (focus == e)
         *curitem = item;
     if (e->active ())
         ensureItemVisible (item);
-    for (NodePtr c = e->lastChild (); c; c = c->previousSibling ())
+    for (Node *c = e->lastChild (); c; c = c->previousSibling ())
         populate (c, focus, root, item, curitem);
     if (e->isElementNode ()) {
-        AttributePtr a = convertNode<Element> (e)->attributes ()->first ();
+        Attribute *a = static_cast <Element *> (e)->attributes ()->first ();
         if (a) {
             root->have_dark_nodes = true;
             if (root->show_all_nodes) {
@@ -219,7 +233,7 @@ KDE_NO_EXPORT PlayListItem * PlayListView::populate
             default:
                 if (pt > Node::play_type_none)
                     pix = &video_pix;
-                else 
+                else
                     pix = item->firstChild ()
                         ? e->auxiliaryNode ()
                           ? &auxiliary_pix : &folder_pix
@@ -286,7 +300,7 @@ KDE_NO_EXPORT void PlayListView::updateTrees () {
     }
 }
 
-KDE_NO_EXPORT void PlayListView::updateTree (RootPlayListItem * ritem, NodePtr active, bool select) {
+void PlayListView::updateTree (RootPlayListItem * ritem, NodePtr active, bool select) {
     bool set_open = ritem->id == 0 || (ritem ? ritem->isOpen () : false);
     m_ignore_expanded = true;
     PlayListItem * curitem = 0L;
@@ -294,6 +308,12 @@ KDE_NO_EXPORT void PlayListView::updateTree (RootPlayListItem * ritem, NodePtr a
         delete ritem->firstChild ();
     if (!ritem->node)
         return;
+    if (!ritem->show_all_nodes)
+        for (NodePtr n = active; n; n = n->parentNode ()) {
+            active = n;
+            if (n->expose ())
+                break;
+        }
     populate (ritem->node, active, ritem, 0L, &curitem);
     if (set_open && ritem->firstChild () && !ritem->isOpen ())
         setOpen (ritem, true);
@@ -307,7 +327,7 @@ KDE_NO_EXPORT void PlayListView::updateTree (RootPlayListItem * ritem, NodePtr a
 }
 
 void PlayListView::selectItem (const QString & txt) {
-    QListViewItem * item = selectedItem ();
+    Q3ListViewItem * item = selectedItem ();
     if (item && item->text (0) == txt)
         return;
     item = findItem (txt, 0);
@@ -317,12 +337,12 @@ void PlayListView::selectItem (const QString & txt) {
     }
 }
 
-KDE_NO_EXPORT QDragObject * PlayListView::dragObject () {
+KDE_NO_EXPORT Q3DragObject * PlayListView::dragObject () {
     PlayListItem * item = static_cast <PlayListItem *> (selectedItem ());
     if (item && item->node) {
         QString txt = item->node->isPlayable ()
             ? item->node->mrl ()->src : item->node->outerXML ();
-        QTextDrag * drag = new QTextDrag (txt, this);
+        Q3TextDrag * drag = new Q3TextDrag (txt, this);
         last_drag_tree_id = rootItem (item)->id;
         m_last_drag = item->node;
         drag->setPixmap (*item->pixmap (0));
@@ -335,29 +355,27 @@ KDE_NO_EXPORT QDragObject * PlayListView::dragObject () {
 
 KDE_NO_EXPORT void PlayListView::setFont (const QFont & fnt) {
     setTreeStepSize (QFontMetrics (fnt).boundingRect ('m').width ());
-    KListView::setFont (fnt);
+    K3ListView::setFont (fnt);
 }
 
-KDE_NO_EXPORT void PlayListView::contextMenuItem (QListViewItem * vi, const QPoint & p, int) {
+KDE_NO_EXPORT void PlayListView::contextMenuItem (Q3ListViewItem * vi, const QPoint & p, int) {
     if (vi) {
         PlayListItem * item = static_cast <PlayListItem *> (vi);
         if (item->node || item->m_attr) {
             RootPlayListItem * ritem = rootItem (vi);
             if (m_itemmenu->count () > 0) {
-                m_find->unplug (m_itemmenu);
-                m_find_next->unplug (m_itemmenu);
+                m_find->setVisible (false);
+                m_find_next->setVisible (false);
                 m_itemmenu->clear ();
             }
-            m_itemmenu->insertItem (KGlobal::iconLoader ()->loadIconSet
-                    (QString ("editcopy"), KIcon::Small, 0, true),
+            m_itemmenu->insertItem (KIcon ("edit-copy"),
                     i18n ("&Copy to Clipboard"),
                     this, SLOT (copyToClipboard ()), 0, 0);
             if (item->m_attr ||
                     (item->node && (item->node->isPlayable () ||
                                     item->node->isDocument ()) &&
                      item->node->mrl ()->bookmarkable))
-                m_itemmenu->insertItem (KGlobal::iconLoader ()->loadIconSet
-                        (QString ("bookmark_add"), KIcon::Small, 0, true),
+                m_itemmenu->insertItem (KIcon ("bookmark-new"),
                         i18n ("&Add Bookmark"),
                         this, SLOT (addBookMark ()), 0, 1);
             if (ritem->have_dark_nodes) {
@@ -366,16 +384,16 @@ KDE_NO_EXPORT void PlayListView::contextMenuItem (QListViewItem * vi, const QPoi
                 m_itemmenu->setItemChecked (2, ritem->show_all_nodes);
             }
             m_itemmenu->insertSeparator ();
-            m_find->plug (m_itemmenu);
-            m_find_next->plug (m_itemmenu);
+            m_find->setVisible (true);
+            m_find_next->setVisible (true);
             emit prepareMenu (item, m_itemmenu);
             m_itemmenu->exec (p);
         }
     } else
-        m_view->controlPanel ()->popupMenu ()->exec (p);
+        m_view->controlPanel ()->popupMenu->exec (p);
 }
 
-void PlayListView::itemExpanded (QListViewItem * item) {
+void PlayListView::itemExpanded (Q3ListViewItem * item) {
     if (!m_ignore_expanded && item->childCount () == 1) {
         PlayListItem * child_item = static_cast<PlayListItem*>(item->firstChild ());
         child_item->setOpen (rootItem (item)->show_all_nodes ||
@@ -383,7 +401,7 @@ void PlayListView::itemExpanded (QListViewItem * item) {
     }
 }
 
-RootPlayListItem * PlayListView::rootItem (QListViewItem * item) const {
+RootPlayListItem * PlayListView::rootItem (Q3ListViewItem * item) const {
     if (!item)
         return 0L;
     while (item->parent ())
@@ -416,7 +434,7 @@ void PlayListView::addBookMark () {
     if (item->node) {
         Mrl * mrl = item->node->mrl ();
         KURL url (mrl ? mrl->src : QString (item->node->nodeName ()));
-        emit addBookMark (mrl->pretty_name.isEmpty () ? url.prettyURL () : mrl->pretty_name, url.url ());
+        emit addBookMark (mrl->title.isEmpty () ? url.prettyUrl () : mrl->title, url.url ());
     }
 }
 
@@ -444,7 +462,7 @@ KDE_NO_EXPORT void PlayListView::showAllNodes(RootPlayListItem *ri, bool show) {
 }
 
 KDE_NO_EXPORT bool PlayListView::acceptDrag (QDropEvent * de) const {
-    QListViewItem * item = itemAt (contentsToViewport (de->pos ()));
+    Q3ListViewItem * item = itemAt (contentsToViewport (de->pos ()));
     if (item && (de->source () == this || isDragValid (de))) {
         RootPlayListItem * ritem = rootItem (item);
         return ritem->flags & AllowDrops;
@@ -452,7 +470,7 @@ KDE_NO_EXPORT bool PlayListView::acceptDrag (QDropEvent * de) const {
     return false;
 }
 
-KDE_NO_EXPORT void PlayListView::itemDropped (QDropEvent * de, QListViewItem *after) {
+KDE_NO_EXPORT void PlayListView::itemDropped (QDropEvent * de, Q3ListViewItem *after) {
     if (!after) { // could still be a descendent
         after = itemAt (contentsToViewport (de->pos ()));
         if (after)
@@ -464,19 +482,17 @@ KDE_NO_EXPORT void PlayListView::itemDropped (QDropEvent * de, QListViewItem *af
             return;
         NodePtr n = static_cast <PlayListItem *> (after)->node;
         bool valid = n && (!n->isDocument () || n->hasChildNodes ());
-        KURL::List sl;
-        if (KURLDrag::canDecode (de)) {
-            KURLDrag::decode (de, sl);
-        } else if (QTextDrag::canDecode (de)) {
+        KUrl::List uris = KUrl::List::fromMimeData (de->mimeData());
+        if (uris.isEmpty() && Q3TextDrag::canDecode (de)) {
             QString text;
-            QTextDrag::decode (de, text);
-            sl.push_back (KURL (text));
+            Q3TextDrag::decode (de, text);
+            uris.push_back (KURL (text));
         }
-        if (valid && sl.size () > 0) {
+        if (valid && uris.size () > 0) {
             bool as_child = n->isDocument () || n->hasChildNodes ();
             NodePtr d = n->document ();
-            for (int i = sl.size (); i > 0; i--) {
-                Node * ni = new KMPlayer::GenericURL (d, sl[i-1].url ());
+            for (int i = uris.size (); i > 0; i--) {
+                Node * ni = new KMPlayer::GenericURL (d, uris[i-1].url ());
                 if (as_child)
                     n->insertBefore (ni, n->firstChild ());
                 else
@@ -492,14 +508,14 @@ KDE_NO_EXPORT void PlayListView::itemDropped (QDropEvent * de, QListViewItem *af
         m_view->dropEvent (de);
 }
 
-KDE_NO_EXPORT void PlayListView::itemIsRenamed (QListViewItem * qitem) {
+KDE_NO_EXPORT void PlayListView::itemIsRenamed (Q3ListViewItem * qitem) {
     PlayListItem * item = static_cast <PlayListItem *> (qitem);
     if (item->node) {
         RootPlayListItem * ri = rootItem (qitem);
         if (!ri->show_all_nodes && item->node->isEditable ()) {
             item->node->setNodeName (item->text (0));
-            if (item->node->mrl ()->pretty_name.isEmpty ())
-                item->setText (0, KURL (item->node->mrl ()->src).prettyURL (0, KURL::StripFileProtocol));
+            if (item->node->caption ().isEmpty ())
+                item->setText (0, KURL (item->node->mrl ()->src).pathOrUrl ());
         } else // restore damage ..
             updateTree (ri, item->node, true);
     } else if (item->m_attr) {
@@ -518,29 +534,29 @@ KDE_NO_EXPORT void PlayListView::itemIsRenamed (QListViewItem * qitem) {
     }
 }
 
-KDE_NO_EXPORT void PlayListView::itemIsSelected (QListViewItem * qitem) {
+KDE_NO_EXPORT void PlayListView::itemIsSelected (Q3ListViewItem * qitem) {
     RootPlayListItem * ri = rootItem (qitem);
     setItemsRenameable (ri && (ri->flags & TreeEdit) && ri != qitem);
 }
 
-KDE_NO_EXPORT void PlayListView::rename (QListViewItem * qitem, int c) {
+KDE_NO_EXPORT void PlayListView::rename (Q3ListViewItem * qitem, int c) {
     PlayListItem * item = static_cast <PlayListItem *> (qitem);
     if (rootItem (qitem)->show_all_nodes && item && item->m_attr) {
         PlayListItem * pi = static_cast <PlayListItem *> (qitem->parent ());
         if (pi && pi->node && pi->node->isEditable ())
-            KListView::rename (item, c);
+            K3ListView::rename (item, c);
     } else if (item && item->node && item->node->isEditable ()) {
         if (!rootItem (qitem)->show_all_nodes &&
                 item->node->isPlayable () &&
-                item->node->mrl ()->pretty_name.isEmpty ())
+                item->node->mrl ()->title.isEmpty ())
             // populate() has crippled src, restore for editing 
             item->setText (0, item->node->mrl ()->src);
-        KListView::rename (item, c);
+        K3ListView::rename (item, c);
     }
 }
 
 KDE_NO_EXPORT void PlayListView::editCurrent () {
-    QListViewItem * qitem = selectedItem ();
+    Q3ListViewItem * qitem = selectedItem ();
     if (qitem) {
         RootPlayListItem * ri = rootItem (qitem);
         if (ri && (ri->flags & TreeEdit) && ri != qitem)
@@ -551,29 +567,29 @@ KDE_NO_EXPORT void PlayListView::editCurrent () {
 KDE_NO_EXPORT void PlayListView::slotFind () {
     m_current_find_elm = 0L;
     if (!m_find_dialog) {
-        m_find_dialog = new KFindDialog (false, this, "kde_kmplayer_find", KFindDialog::CaseSensitive);
+        m_find_dialog = new KFindDialog (this, KFind::CaseSensitive);
         m_find_dialog->setHasSelection (false);
         connect(m_find_dialog, SIGNAL(okClicked ()), this, SLOT(slotFindOk ()));
     } else
-        m_find_dialog->setPattern (QString::null);
+        m_find_dialog->setPattern (QString ());
     m_find_dialog->show ();
 }
 
-static QListViewItem * findNodeInTree (NodePtr n, QListViewItem * item) {
-    //kdDebug () << "item:" << item->text (0) << " n:" << (n ? n->nodeName () : "null" )  <<endl;
+static Q3ListViewItem * findNodeInTree (NodePtr n, Q3ListViewItem * item) {
+    //kDebug () << "item:" << item->text (0) << " n:" << (n ? n->nodeName () : "null" );
     PlayListItem * pi = static_cast <PlayListItem *> (item);
     if (!n || !pi->node)
         return 0L;
     if (n == pi->node)
         return item;
-    for (QListViewItem * ci = item->firstChild(); ci; ci = ci->nextSibling ()) {
-        //kdDebug () << "ci:" << ci->text (0) << " n:" << n->nodeName () <<endl;
-        QListViewItem * vi = findNodeInTree (n, ci);
+    for (Q3ListViewItem * ci = item->firstChild(); ci; ci = ci->nextSibling ()) {
+        //kDebug () << "ci:" << ci->text (0) << " n:" << n->nodeName ();
+        Q3ListViewItem * vi = findNodeInTree (n, ci);
         if (vi)
             return vi;
     }
     return 0L;
-    
+
 }
 
 KDE_NO_EXPORT void PlayListView::slotFindOk () {
@@ -582,7 +598,7 @@ KDE_NO_EXPORT void PlayListView::slotFindOk () {
     m_find_dialog->hide ();
     long opt = m_find_dialog->options ();
     current_find_tree_id = 0;
-    if (opt & KFindDialog::FromCursor && currentItem ()) {
+    if (opt & KFind::FromCursor && currentItem ()) {
         PlayListItem * lvi = currentPlayListItem ();
         if (lvi && lvi->node) {
              m_current_find_elm = lvi->node;
@@ -594,7 +610,7 @@ KDE_NO_EXPORT void PlayListView::slotFindOk () {
                 m_current_find_elm = pi->node;
             }
         }
-    } else if (!(opt & KFindDialog::FindIncremental))
+    } else if (!(opt & KFind::FindIncremental))
         m_current_find_elm = 0L;
     if (!m_current_find_elm) {
         PlayListItem * lvi = static_cast <PlayListItem *> (firstChild ());
@@ -616,11 +632,11 @@ KDE_NO_EXPORT void PlayListView::slotFindNext () {
         return;
     long opt = m_find_dialog->options ();
     QRegExp regexp;
-    if (opt & KFindDialog::RegularExpression)
-        regexp = str;
-    bool cs = (opt & KFindDialog::CaseSensitive);
+    if (opt & KFind::RegularExpression)
+        regexp = QRegExp (str);
+    bool cs = (opt & KFind::CaseSensitive);
     bool found = false;
-    NodePtr node, n = m_current_find_elm;
+    Node *node = NULL, *n = m_current_find_elm.ptr ();
     RootPlayListItem * ri = rootItem (current_find_tree_id);
     while (!found && n) {
         if (ri->show_all_nodes || n->expose ()) {
@@ -629,27 +645,27 @@ KDE_NO_EXPORT void PlayListView::slotFindNext () {
             if (elm && !ri->show_all_nodes) {
                 Mrl * mrl = n->mrl ();
                 if (mrl) {
-                    if (mrl->pretty_name.isEmpty ()) {
+                    if (mrl->title.isEmpty ()) {
                         if (!mrl->src.isEmpty())
-                            val = KURL(mrl->src).prettyURL();
+                            val = KURL(mrl->src).prettyUrl();
                     } else
-                        val = mrl->pretty_name;
+                        val = mrl->title;
                 }
             } else if (!elm)
                 val = n->nodeValue ();
-            if (((opt & KFindDialog::RegularExpression) &&
+            if (((opt & KFind::RegularExpression) &&
                     val.find (regexp, 0) > -1) ||
-                    (!(opt & KFindDialog::RegularExpression) &&
+                    (!(opt & KFind::RegularExpression) &&
                      val.find (str, 0, cs) > -1)) {
                 node = n;
                 m_current_find_attr = 0L;
                 found = true;
             } else if (elm && ri->show_all_nodes) {
-                for (AttributePtr a = convertNode <Element> (n)->attributes ()->first (); a; a = a->nextSibling ()) {
+                for (Attribute *a = static_cast <Element *> (n)->attributes ()->first (); a; a = a->nextSibling ()) {
                     QString attr = a->name ().toString ();
-                    if (((opt & KFindDialog::RegularExpression) &&
+                    if (((opt & KFind::RegularExpression) &&
                                 (attr.find (regexp, 0) || a->value ().find (regexp, 0) > -1)) ||
-                                (!(opt & KFindDialog::RegularExpression) &&
+                                (!(opt & KFind::RegularExpression) &&
                                  (attr.find (str, 0, cs) > -1 || a->value ().find (str, 0, cs) > -1))) {
                         node = n;
                         m_current_find_attr = a;
@@ -660,7 +676,7 @@ KDE_NO_EXPORT void PlayListView::slotFindNext () {
             }
         }
         if (n) { //set pointer to next
-            if (opt & KFindDialog::FindBackwards) {
+            if (opt & KFind::FindBackwards) {
                 if (n->lastChild ()) {
                     n = n->lastChild ();
                 } else if (n->previousSibling ()) {
@@ -699,12 +715,12 @@ KDE_NO_EXPORT void PlayListView::slotFindNext () {
         }
     }
     m_current_find_elm = n;
-    kdDebug () << " search for " << str << "=" << (node ? node->nodeName () : "not found") << " next:" << (n ? n->nodeName () : " not found") << endl;
+    kDebug () << " search for " << str << "=" << (node ? node->nodeName () : "not found") << " next:" << (n ? n->nodeName () : " not found");
     if (found) {
-        QListViewItem * fc = findNodeInTree (node, ri);
+        Q3ListViewItem * fc = findNodeInTree (node, ri);
         if (!fc) {
             m_current_find_elm = 0L;
-            kdDebug () << "node not found in tree tree:" << ri->id << endl;
+            kDebug () << "node not found in tree tree:" << ri->id;
         } else {
             setSelected (fc, true);
             if (m_current_find_attr && fc->firstChild () && fc->firstChild ()->firstChild ())
