@@ -20,28 +20,26 @@
 
 #undef Always
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qcheckbox.h>
-#include <qtable.h>
 #include <qstringlist.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
-#include <qgroupbox.h>
+#include <Q3GroupBox>
 #include <qwhatsthis.h>
 #include <qtabwidget.h>
 #include <qslider.h>
-#include <qbuttongroup.h>
+#include <Q3ButtonGroup>
 #include <qspinbox.h>
 #include <qmessagebox.h>
 #include <qmap.h>
 #include <qtimer.h>
 #include <qfont.h>
+#include <Q3ListBox>
+#include <QAbstractButton>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -54,28 +52,26 @@
 #include <kcolorbutton.h>
 #include <kurlrequester.h>
 #include <kfontdialog.h>
-
 #include "pref.h"
 #include "kmplayerpartbase.h"
 #include "kmplayerprocess.h"
+#include "mediaobject.h"
 #include "kmplayerconfig.h"
 
-
 using namespace KMPlayer;
 
 KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * settings)
-: KDialogBase (IconList, i18n ("Preferences"),
-		Help|Default|Ok|Apply|Cancel, Ok, player->view (), 0, false)
+: KPageDialog (player->view ())
 {
-    QFrame *frame;
-    QTabWidget * tab;
-    QStringList hierarchy; // typo? :)
-    QVBoxLayout *vlay;
+    setFaceType (KPageDialog::List);
+    setCaption (i18n ("Preferences"));
+    setButtons (KDialog::Ok | KDialog::Cancel | KDialog::Apply);
+    setDefaultButton (KDialog::Ok);
 
-    frame = addPage(i18n("General Options"), QString::null, KGlobal::iconLoader()->loadIcon (QString ("kmplayer"), KIcon::NoGroup, 32));
-    vlay = new QVBoxLayout(frame, marginHint(), spacingHint());
-    tab = new QTabWidget (frame);
-    vlay->addWidget (tab);
+    KVBox *page = new KVBox (this);
+    KPageWidgetItem *item = addPage (page, i18n ("General Options"));
+    item->setIcon (KIcon ("kmplayer"));
+    QTabWidget *tab = new QTabWidget (page);
     m_GeneralPageGeneral = new PrefGeneralPageGeneral (tab, settings);
     tab->insertTab (m_GeneralPageGeneral, i18n("General"));
     m_GeneralPageLooks = new PrefGeneralPageLooks (tab, settings);
@@ -85,18 +81,18 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     tab->insertTab (m_GeneralPageOutput, i18n("Output"));
     entries.insert (i18n("General Options"), tab);
 
-    frame = addPage (i18n ("Source"), QString::null, KGlobal::iconLoader()->loadIcon (QString ("source"), KIcon::NoGroup, 32));
-    vlay = new QVBoxLayout (frame, marginHint(), spacingHint());
-    tab = new QTabWidget (frame);
-    vlay->addWidget (tab);
+    page = new KVBox (this);
+    m_url_item = addPage (page, i18n ("Source"));
+    m_url_item->setIcon (KIcon ("document-import"));
+    tab = new QTabWidget (page);
     m_SourcePageURL = new PrefSourcePageURL (tab);
     tab->insertTab (m_SourcePageURL, i18n ("URL"));
     entries.insert (i18n("Source"), tab);
 
-    frame = addPage (i18n ("Recording"), QString::null, KGlobal::iconLoader()->loadIcon (QString ("video"), KIcon::NoGroup, 32));
-    vlay = new QVBoxLayout (frame, marginHint(), spacingHint());
-    tab = new QTabWidget (frame);
-    vlay->addWidget (tab);
+    page = new KVBox (this);
+    m_record_item = addPage (page, i18n ("Recording"));
+    m_record_item->setIcon (KIcon ("folder-video"));
+    tab = new QTabWidget (page);
 
     int recorders_count = 3;
     m_MEncoderPage = new PrefMEncoderPage (tab, player);
@@ -110,7 +106,7 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     m_MPlayerDumpstreamPage = new PrefMPlayerDumpstreamPage (tab, player);
     // tab->insertTab (m_MPlayerDumpstreamPage, i18n ("MPlayer -dumpstream"));
     m_FFMpegPage->next = m_MPlayerDumpstreamPage;
-#ifdef HAVE_XINE
+#ifdef KMPLAYER_WITH_XINE
     recorders_count = 4;
     m_XinePage = new PrefXinePage (tab, player);
     // tab->insertTab (m_XinePage, i18n ("Xine"));
@@ -121,54 +117,58 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     tab->setCurrentPage (0);
     entries.insert (i18n("Recording"), tab);
 
-    frame = addPage (i18n ("Output Plugins"), QString::null, KGlobal::iconLoader()->loadIcon (QString ("image"), KIcon::NoGroup, 32));
-    vlay = new QVBoxLayout(frame, marginHint(), spacingHint());
-    tab = new QTabWidget (frame);
-    vlay->addWidget (tab);
+    page = new KVBox (this);
+    item = addPage (page, i18n ("Output Plugins"));
+    item->setIcon (KIcon ("folder-image"));
+    tab = new QTabWidget (page);
     m_OPPagePostproc = new PrefOPPagePostProc (tab);
     tab->insertTab (m_OPPagePostproc, i18n ("Postprocessing"));
     entries.insert (i18n("Postprocessing"), tab);
 
     for (PreferencesPage * p = settings->pagelist; p; p = p->next)
         addPrefPage (p);
-        
 
     connect (this, SIGNAL (defaultClicked ()), SLOT (confirmDefaults ()));
 }
 
 KDE_NO_EXPORT void Preferences::setPage (const char * name) {
-    QObject * o = child (name, "QFrame");
-    if (!o) return;
-    QFrame * page = static_cast <QFrame *> (o);
-    QWidget * w = page->parentWidget ();
-    while (w && !w->inherits ("QTabWidget"))
-        w = w->parentWidget ();
-    if (!w) return;
-    QTabWidget * t = static_cast <QTabWidget*> (w);
-    t->setCurrentPage (t->indexOf(page));
-    if (!t->parentWidget() || !t->parentWidget()->inherits ("QFrame"))
-        return;
-    showPage (pageIndex (t->parentWidget ()));
+    KPageWidgetItem *item = NULL;
+    if (!strcmp (name, "RecordPage"))
+        item = m_record_item;
+    else if (!strcmp (name, "URLPage"))
+        item = m_url_item;
+    if (item) {
+        setCurrentPage (item);
+        KVBox *page = findChild <KVBox *> (name);
+        if (!page)
+            return;
+        QWidget * w = page->parentWidget ();
+        while (w && !qobject_cast <QTabWidget *> (w))
+            w = w->parentWidget ();
+        if (!w)
+            return;
+        QTabWidget *t = static_cast <QTabWidget*> (w);
+        t->setCurrentPage (t->indexOf(page));
+    }
 }
 
 KDE_NO_EXPORT void Preferences::addPrefPage (PreferencesPage * page) {
     QString item, subitem, icon;
-    QFrame * frame;
-    QTabWidget * tab;
-    QVBoxLayout *vlay;
+    KPageWidgetItem *witem;
+    QTabWidget *tab;
     page->prefLocation (item, icon, subitem);
     if (item.isEmpty ())
         return;
     QMap<QString, QTabWidget *>::iterator en_it = entries.find (item);
     if (en_it == entries.end ()) {
-        frame = addPage (item, QString::null, KGlobal::iconLoader()->loadIcon ((icon), KIcon::NoGroup, 32));
-        vlay = new QVBoxLayout (frame, marginHint(), spacingHint());
-        tab = new QTabWidget (frame);
-        vlay->addWidget (tab);
+        KVBox *page = new KVBox (this);
+        witem = addPage (page, item);
+        witem->setIcon (KIcon (icon));
+        tab = new QTabWidget (page);
         entries.insert (item, tab);
     } else
         tab = en_it.data ();
-    frame = page->prefPage (tab);
+    QFrame *frame = page->prefPage (tab);
     tab->insertTab (frame, subitem);
 }
 
@@ -201,41 +201,42 @@ KDE_NO_CDTOR_EXPORT Preferences::~Preferences() {
 }
 
 KDE_NO_CDTOR_EXPORT PrefGeneralPageGeneral::PrefGeneralPageGeneral(QWidget *parent, Settings *)
-: QFrame (parent, "GeneralPage")
+: KVBox (parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this, 5, 2);
+    setMargin (5);
+    setSpacing (2);
 
-    QGroupBox *windowbox = new QGroupBox(1, Qt::Vertical, i18n("Window"), this);
+    Q3GroupBox *windowbox = new Q3GroupBox(1, Qt::Vertical, i18n("Window"), this);
     QWidget * wbox = new QWidget (windowbox);
     QWidget * bbox = new QWidget (wbox);
     QGridLayout * gridlayout = new QGridLayout (bbox, 2, 2);
     keepSizeRatio = new QCheckBox (i18n ("Keep size ratio"), bbox, 0);
-    QWhatsThis::add(keepSizeRatio, i18n("When checked, movie will keep its aspect ratio\nwhen window is resized"));
+    QWhatsThis::add(keepSizeRatio, i18n("When checked, the movie will keep its aspect ratio\nwhen the window is resized."));
     dockSysTray = new QCheckBox (i18n ("Dock in system tray"), bbox, 0);
-    QWhatsThis::add (dockSysTray, i18n ("When checked, an icon of KMPlayer will be added to the system tray.\nWhen clicked it will hide KMPlayer's main window and removing KMPlayer's taskbar button."));
+    QWhatsThis::add (dockSysTray, i18n ("When checked, an icon for KMPlayer will be added to the system tray.\nWhen clicked, it will hide KMPlayer's main window and remove KMPlayer's task bar button."));
     autoResize = new QCheckBox (i18n ("Auto resize to video sizes"), bbox);
-    QWhatsThis::add (autoResize, i18n("When checked, KMPlayer will resize to movie sizes\nwhen video starts"));
+    QWhatsThis::add (autoResize, i18n("When checked, KMPlayer will resize to movie sizes\nwhen video starts."));
     gridlayout->addWidget (keepSizeRatio, 0, 0);
     gridlayout->addWidget (dockSysTray, 1, 0);
     gridlayout->addWidget (autoResize, 0, 1);
-    sizesChoice = new QButtonGroup (2, Qt::Vertical, wbox);
+    sizesChoice = new Q3ButtonGroup (2, Qt::Vertical, wbox);
     new QRadioButton (i18n("Remember window size on exit"), sizesChoice);
     new QRadioButton (i18n("Always start with fixed size"), sizesChoice);
     QVBoxLayout * vbox = new QVBoxLayout (wbox, 2, 2);
     vbox->addWidget (bbox);
     vbox->addWidget (sizesChoice);
 
-    QGroupBox *playbox =new QGroupBox(4, Qt::Vertical,i18n("Playing"),this);
+    Q3GroupBox *playbox =new Q3GroupBox(4, Qt::Vertical,i18n("Playing"),this);
     loop = new QCheckBox (i18n("Loop"), playbox);
     QWhatsThis::add(loop, i18n("Makes current movie loop"));
-    framedrop = new QCheckBox (i18n ("Allow framedrops"), playbox);
+    framedrop = new QCheckBox (i18n ("Allow frame drops"), playbox);
     QWhatsThis::add (framedrop, i18n ("Allow dropping frames for better audio and video synchronization"));
     adjustvolume = new QCheckBox(i18n("Auto set volume on start"), playbox);
     QWhatsThis::add (adjustvolume, i18n ("When a new source is selected, the volume will be set according the volume control"));
     adjustcolors = new QCheckBox(i18n("Auto set colors on start"), playbox);
     QWhatsThis::add (adjustcolors, i18n ("When a movie starts, the colors will be set according the sliders for colors"));
 
-    QGroupBox * gbox =new QGroupBox (1, Qt::Vertical, i18n("Control Panel"), this);
+    Q3GroupBox * gbox =new Q3GroupBox (1, Qt::Vertical, i18n("Control Panel"), this);
     bbox =new QWidget (gbox);
     //QGroupBox * bbox = gbox;
     gridlayout = new QGridLayout (bbox, 3, 2);
@@ -260,20 +261,15 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageGeneral::PrefGeneralPageGeneral(QWidget *pare
     seekLayout->addItem(new QSpacerItem(0,0,QSizePolicy::Minimum, QSizePolicy::Minimum));
     gridlayout->addMultiCellLayout (seekLayout, 2, 2, 0, 1);
 
-    layout->addWidget (windowbox);
-    layout->addWidget (playbox);
-    layout->addWidget (gbox);
-    //layout->addWidget(autoHideSlider);
-    layout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+    layout()->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
 }
 
 KDE_NO_CDTOR_EXPORT PrefGeneralPageLooks::PrefGeneralPageLooks (QWidget *parent, Settings * settings)
- : QFrame (parent, "LooksPage"),
-   colors (settings->colors),
-   fonts (settings->fonts) {
-    QVBoxLayout *layout = new QVBoxLayout(this, 5, 2);
+ : KVBox (parent), colors (settings->colors), fonts (settings->fonts) {
+    setMargin (5);
+    setSpacing (2);
 
-    QGroupBox *colorbox= new QGroupBox(2, Qt::Horizontal, i18n("Colors"), this);
+    Q3GroupBox *colorbox= new Q3GroupBox(2, Qt::Horizontal, i18n("Colors"), this);
     colorscombo = new QComboBox (colorbox);
     for (int i = 0; i < int (ColorSetting::last_target); i++)
         colorscombo->insertItem (colors[i].title);
@@ -285,7 +281,7 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageLooks::PrefGeneralPageLooks (QWidget *parent,
     connect (colorbutton, SIGNAL (changed (const QColor &)),
             this, SLOT (colorCanged (const QColor &)));
 
-    QGroupBox *fontbox = new QGroupBox (2,Qt::Horizontal, i18n ("Fonts"), this);
+    Q3GroupBox *fontbox = new Q3GroupBox (2,Qt::Horizontal, i18n ("Fonts"), this);
     fontscombo = new QComboBox (fontbox);
     for (int i = 0; i < int (FontSetting::last_target); i++)
         fontscombo->insertItem (fonts[i].title);
@@ -297,9 +293,7 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageLooks::PrefGeneralPageLooks (QWidget *parent,
     fontbutton->setFont (fonts[0].font);
     connect (fontbutton, SIGNAL (clicked ()), this, SLOT (fontClicked ()));
 
-    layout->addWidget (colorbox);
-    layout->addWidget (fontbox);
-    layout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+    layout()->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
 }
 
 KDE_NO_EXPORT void PrefGeneralPageLooks::colorItemChanged (int c) {
@@ -329,16 +323,19 @@ KDE_NO_EXPORT void PrefGeneralPageLooks::fontClicked () {
 }
 
 KDE_NO_CDTOR_EXPORT PrefSourcePageURL::PrefSourcePageURL (QWidget *parent)
-: QFrame (parent, "URLPage")
+: KVBox (parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout (this, 5, 5);
+    setObjectName ("URLPage");
+    setMargin (5);
+    setSpacing (2);
+
     QHBoxLayout * urllayout = new QHBoxLayout ();
     QHBoxLayout * sub_urllayout = new QHBoxLayout ();
     QLabel *urlLabel = new QLabel (i18n ("Location:"), this, 0);
     urllist = new KComboBox (true, this);
     urllist->setMaxCount (20);
     urllist->setDuplicatesEnabled (false); // not that it helps much :(
-    url = new KURLRequester (urllist, this);
+    url = new KUrlRequester (urllist, this);
     QWhatsThis::add (url, i18n ("Location of the playable item"));
     //url->setShowLocalProtocol (true);
     url->setSizePolicy (QSizePolicy (QSizePolicy::Expanding, QSizePolicy::Preferred));
@@ -346,32 +343,35 @@ KDE_NO_CDTOR_EXPORT PrefSourcePageURL::PrefSourcePageURL (QWidget *parent)
     sub_urllist = new KComboBox (true, this);
     sub_urllist->setMaxCount (20);
     sub_urllist->setDuplicatesEnabled (false); // not that it helps much :(
-    sub_url = new KURLRequester (sub_urllist, this);
+    sub_url = new KUrlRequester (sub_urllist, this);
     QWhatsThis::add (sub_url, i18n ("Optional location of a file containing the subtitles of the URL above"));
     sub_url->setSizePolicy (QSizePolicy (QSizePolicy::Expanding, QSizePolicy::Preferred));
-    backend = new QListBox (this);
-    allowhref = new QCheckBox (i18n ("Enable 'Click to Play' support"), this);
-    QWhatsThis::add (allowhref, i18n ("Support for WEB pages having a start image"));
-    layout->addWidget (allowhref);
+    backend = new Q3ListBox (this);
+    clicktoplay = new QCheckBox (i18n ("Load on demand"), this);
+    QWhatsThis::add (clicktoplay, i18n ("When enabled, all embedded movies will start with a image that needs to be clicked to start the video playback"));
+    grabhref = new QCheckBox (i18n ("Grab image when 'Click to Play' detected"), this);
+    QWhatsThis::add (grabhref, i18n ("When enabled and a HTML object has a HREF attribute, grab and save an image of the first frame of initial link. This image will be shown instead of a default picture."));
     urllayout->addWidget (urlLabel);
     urllayout->addWidget (url);
-    layout->addLayout (urllayout);
+    static_cast <QBoxLayout *>(layout())->addLayout (urllayout);
     sub_urllayout->addWidget (sub_urlLabel);
     sub_urllayout->addWidget (sub_url);
-    layout->addLayout (sub_urllayout);
-    layout->addItem (new QSpacerItem (0, 10, QSizePolicy::Minimum, QSizePolicy::Minimum));
+    static_cast <QBoxLayout *>(layout())->addLayout (sub_urllayout);
+    layout()->addItem (new QSpacerItem (0, 10, QSizePolicy::Minimum, QSizePolicy::Minimum));
     QGridLayout * gridlayout = new QGridLayout (2, 2);
     QLabel *backendLabel = new QLabel (i18n ("Use movie player:"), this, 0);
     //QWhatsThis::add (allowhref, i18n ("Explain this in a few lines"));
     gridlayout->addWidget (backendLabel, 0, 0);
     gridlayout->addWidget (backend, 1, 0);
     gridlayout->addMultiCell (new QSpacerItem (0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum), 0, 1, 1, 1);
-    QGroupBox *cbox = new QGroupBox(1, Qt::Vertical, i18n("Network bandwidth"), this);
+    Q3GroupBox *cbox = new Q3GroupBox(1, Qt::Vertical, i18n("Network bandwidth"), this);
     QWidget * wbox = new QWidget (cbox);
     QGridLayout * bitratelayout = new QGridLayout (wbox, 2, 3, 5);
     prefBitRate = new QLineEdit (wbox);
+    prefBitRate->setValidator( new QIntValidator( prefBitRate ) );
     QWhatsThis::add (prefBitRate, i18n("Sometimes it is possible to choose between various streams given a particular bitrate.\nThis option sets how much bandwidth you would prefer to allocate to video."));
     maxBitRate = new QLineEdit (wbox);
+    maxBitRate->setValidator( new QIntValidator( maxBitRate ) );
     QWhatsThis::add (maxBitRate, i18n("Sometimes it is possible to choose between various streams given a particular bitrate.\nThis option sets the maximum bandwidth you have available for video."));
     bitratelayout->addWidget(new QLabel(i18n("Preferred bitrate:"), wbox), 0, 0);
     bitratelayout->addWidget (prefBitRate, 0, 1);
@@ -379,9 +379,8 @@ KDE_NO_CDTOR_EXPORT PrefSourcePageURL::PrefSourcePageURL (QWidget *parent)
     bitratelayout->addWidget (new QLabel(i18n("Maximum bitrate:"), wbox), 1, 0);
     bitratelayout->addWidget (maxBitRate, 1, 1);
     bitratelayout->addWidget (new QLabel (i18n ("kbit/s"), wbox), 1, 2);
-    layout->addLayout (gridlayout);
-    layout->addWidget (cbox);
-    layout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+    static_cast <QBoxLayout *>(layout())->addLayout (gridlayout);
+    layout()->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
     connect (urllist, SIGNAL(textChanged (const QString &)),
              this, SLOT (slotTextChanged (const QString &)));
     connect (sub_urllist, SIGNAL(textChanged (const QString &)),
@@ -395,27 +394,42 @@ KDE_NO_EXPORT void PrefSourcePageURL::slotTextChanged (const QString &) {
     changed = true;
 }
 
-KDE_NO_CDTOR_EXPORT PrefRecordPage::PrefRecordPage (QWidget *parent, PartBase * player, RecorderPage * rl, int rec_len) : QFrame (parent, "RecordPage"), m_player (player), m_recorders (rl), m_recorders_length (rec_len) {
-    QVBoxLayout *layout = new QVBoxLayout (this, 5, 5);
+KDE_NO_CDTOR_EXPORT PrefRecordPage::PrefRecordPage (QWidget *parent,
+        PartBase * player, RecorderPage * rl, int rec_len)
+ : KVBox (player->view ()),
+   m_player (player),
+   m_recorders (rl),
+   m_recorders_length (rec_len),
+   rec_timer (0) {
+    setObjectName ("RecordPage");
+    setMargin (5);
+    setSpacing (2);
+
+    layout()->addItem(new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
+
     QHBoxLayout * urllayout = new QHBoxLayout ();
     QLabel *urlLabel = new QLabel (i18n ("Output file:"), this);
-    url = new KURLRequester ("", this);
-    url->setShowLocalProtocol (true);
+    url = new KUrlRequester (this);
     urllayout->addWidget (urlLabel);
     urllayout->addWidget (url);
+    static_cast <QBoxLayout *>(layout())->addLayout (urllayout);
+
+    layout()->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
     recordButton = new QPushButton (i18n ("Start &Recording"), this);
     connect (recordButton, SIGNAL (clicked ()), this, SLOT (slotRecord ()));
     QHBoxLayout *buttonlayout = new QHBoxLayout;
     buttonlayout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
     buttonlayout->addWidget (recordButton);
-    source = new QLabel (i18n ("Current source: ") + m_player->source ()->prettyName (), this);
-    recorder = new QButtonGroup (m_recorders_length, Qt::Vertical, i18n ("Recorder"), this);
+    source = new QLabel (i18n ("Current source: ") +
+           (m_player->source () ? m_player->source ()->prettyName () : QString ()), this);
+    recorder = new Q3ButtonGroup (m_recorders_length, Qt::Vertical, i18n ("Recorder"), this);
     for (RecorderPage * p = m_recorders; p; p = p->next)
         new QRadioButton (p->name (), recorder);
-    if (m_player->source ())
-        sourceChanged (0L, m_player->source ());
     recorder->setButton(0); // for now
-    replay = new QButtonGroup (4, Qt::Vertical, i18n ("Auto Playback"), this);
+
+    layout()->addItem(new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
+
+    replay = new Q3ButtonGroup (4, Qt::Vertical, i18n ("Auto Playback"), this);
     new QRadioButton (i18n ("&No"), replay);
     new QRadioButton (i18n ("&When recording finished"), replay);
     new QRadioButton (i18n ("A&fter"), replay);
@@ -425,54 +439,69 @@ KDE_NO_CDTOR_EXPORT PrefRecordPage::PrefRecordPage (QWidget *parent, PartBase *
     replaylayout->addWidget (new QLabel (i18n("Time (seconds):"), customreplay));
     replaylayout->addWidget (replaytime);
     replaylayout->addItem (new QSpacerItem (0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum));
-    layout->addWidget (source);
-    layout->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
-    layout->addLayout (urllayout);
-    layout->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
-    layout->addWidget (recorder);
-    layout->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
-    layout->addWidget (replay);
-    layout->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
-    layout->addLayout (buttonlayout);
-    layout->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
-    connect (m_player, SIGNAL (sourceChanged(KMPlayer::Source*,KMPlayer::Source*)), this, SLOT (sourceChanged(KMPlayer::Source*,KMPlayer::Source*)));
-#ifdef HAVE_XINE
+    layout()->addItem(new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Minimum));
+
+    static_cast <QBoxLayout *>(layout())->addLayout (buttonlayout);
+    layout()->addItem (new QSpacerItem (5, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+#ifdef KMPLAYER_WITH_XINE
     connect (recorder, SIGNAL (clicked(int)), this, SLOT(recorderClicked(int)));
 #endif
     connect (replay, SIGNAL (clicked (int)), this, SLOT (replayClicked (int)));
+    connect (player, SIGNAL (recording (bool)), this, SLOT (recording (bool)));
 }
 
-KDE_NO_EXPORT void PrefRecordPage::recordingStarted () {
-    recordButton->setText (i18n ("Stop Recording"));
-    url->setEnabled (false);
-    topLevelWidget ()->hide ();
+PrefRecordPage::~PrefRecordPage () {
+    if (record_doc)
+        record_doc->document ()->dispose ();
 }
 
-KDE_NO_EXPORT void PrefRecordPage::recordingFinished () {
-    recordButton->setText (i18n ("Start Recording"));
-    url->setEnabled (true);
-    QTimer::singleShot (0, m_player, SLOT(recordingStopped())); // removed from PartBase::setSource because PartBase::recordingStopped calls openURL and that will call PartBase::setSource and Qt doesn't like disconnecting/connecting a signal that is current
-}
-
-KDE_NO_EXPORT void PrefRecordPage::sourceChanged (Source * olds, Source * nws) {
-    int id = 0;
-    int nr_recs = 0;
-    if (olds) {
-        disconnect(nws,SIGNAL(startRecording()),this, SLOT(recordingStarted()));
-        disconnect(nws,SIGNAL(stopRecording()),this, SLOT(recordingFinished()));
+KDE_NO_EXPORT void PrefRecordPage::recording (bool on) {
+    kDebug() << "PrefRecordPage::recording " << on << endl;
+    recordButton->setText (on
+            ? i18n ("Stop &Recording")
+            : i18n ("Start &Recording"));
+    url->setEnabled (!on);
+    if (on) {
+        topLevelWidget ()->hide ();
+    } else if (record_doc && record_doc->active ()) {
+        record_doc->deactivate ();
+        if (replay->selectedId () != Settings::ReplayNo) {
+            if (record_doc)
+                record_doc->deactivate ();
+            if (rec_timer)
+                timerEvent (NULL);
+            else
+                m_player->openUrl (
+                        convertNode <RecordDocument> (record_doc)->record_file);
+        }
     }
-    if (nws) {
+}
+
+KDE_NO_EXPORT void PrefRecordPage::showEvent (QShowEvent *e) {
+    Source *src = m_player->source ();
+    if (recordButton->text () == i18n ("Start &Recording") && src &&
+            src->current ()) {
+        int id = 0;
+        int nr_recs = 0;
         for (RecorderPage * p = m_recorders; p; p = p->next, ++id) {
-            QButton * radio = recorder->find (id);
-            bool b = m_player->recorders () [p->recorderName ()]->supports (nws->name ());
+            QAbstractButton * radio = recorder->find (id);
+            bool b = m_player->mediaManager ()->recorderInfos ()
+                [p->recorderName ()]->supports (src->name ());
             radio->setEnabled (b);
             if (b) nr_recs++;
         }
-        source->setText (i18n ("Current Source: ") + nws->prettyName ());
-        connect (nws, SIGNAL(startRecording()), this, SLOT(recordingStarted()));
-        connect (nws, SIGNAL(stopRecording()), this, SLOT(recordingFinished()));
+        source_url = src->current ()->src;
+        source->setText (i18n ("Current Source: ") + source_url);
+        recordButton->setEnabled (nr_recs > 0);
     }
-    recordButton->setEnabled (nr_recs > 0);
+    KVBox::showEvent (e);
+}
+
+KDE_NO_EXPORT void PrefRecordPage::timerEvent (QTimerEvent *) {
+    killTimer (rec_timer);
+    rec_timer = 0;
+    if (record_doc)
+        m_player->openUrl(convertNode<RecordDocument>(record_doc)->record_file);
 }
 
 KDE_NO_EXPORT void PrefRecordPage::recorderClicked (int id) {
@@ -488,59 +517,48 @@ KDE_NO_EXPORT void PrefRecordPage::replayClicked (int id) {
 }
 
 KDE_NO_EXPORT void PrefRecordPage::slotRecord () {
-    connect (m_player->source (), SIGNAL (stopPlaying ()),
-             this, SLOT (playingStopped ()));
-    if (m_player->process () && m_player->process ()->playing ())
-        m_player->process ()->quit ();
-    else
-        playingStopped ();
-}
-
-KDE_NO_EXPORT void PrefRecordPage::playingStopped () {
-    disconnect (m_player->source (), SIGNAL (stopPlaying ()),
-                this, SLOT (playingStopped ()));
     if (!url->lineEdit()->text().isEmpty()) {
+        m_player->source ()->document ()->reset ();
+        kDebug() << "Source resetted" << endl;
         m_player->settings ()->recordfile = url->lineEdit()->text();
         m_player->settings ()->replaytime = replaytime->text ().toInt ();
-#if KDE_IS_VERSION(3,1,90)
         int id = recorder->selectedId ();
         int replayid = replay->selectedId ();
-#else
-        int id = recorder->id (recorder->selected ());
-        int replayid = replay->id (replay->selectedId ());
-#endif
         m_player->settings ()->recorder = Settings::Recorder (id);
         m_player->settings ()->replayoption = Settings::ReplayOption (replayid);
         for (RecorderPage * p = m_recorders; p; p = p->next)
             if (id-- == 0) {
-                p->record ();
+                if (record_doc) {
+                    if (record_doc->active ())
+                        record_doc->reset ();
+                    record_doc->document ()->dispose ();
+                }
+                record_doc = new RecordDocument (
+                        source_url,
+                        url->lineEdit()->text(),
+                        p->recorderName (),
+                        !strcmp (p->recorderName (), "xine"), // FIXME
+                        m_player->source ());
+                p->startRecording ();
+                record_doc->activate ();
+                if (replay->selectedId () == Settings::ReplayAfter) {
+                    double t = replaytime->text ().toDouble ();
+                    if (t > 0.01)
+                        rec_timer = startTimer (int (t * 1000));
+                }
                 break;
             }
     }
 }
 
 KDE_NO_CDTOR_EXPORT RecorderPage::RecorderPage (QWidget *parent, PartBase * player)
- : QFrame (parent), next (0L), m_player (player) {}
-
-KDE_NO_EXPORT void RecorderPage::record () {
-    Process * proc = m_player->recorders () [recorderName ()];
-    m_player->setRecorder (recorderName ());
-    Recorder * rec = dynamic_cast <Recorder *> (proc);
-    if (!proc->playing ()) {
-        if (m_player->process ())
-            m_player->process ()->quit ();
-        rec->setURL (KURL (m_player->settings ()->recordfile));
-        proc->setSource (m_player->source ());
-        proc->ready (0L);
-    } else {
-        rec->setURL (KURL ());
-        proc->stop ();
-    }
-}
+ : KVBox (parent), next (0L), m_player (player) {}
 
 KDE_NO_CDTOR_EXPORT PrefMEncoderPage::PrefMEncoderPage (QWidget *parent, PartBase * player) : RecorderPage (parent, player) {
-    QVBoxLayout *layout = new QVBoxLayout (this, 5, 5);
-    format = new QButtonGroup (3, Qt::Vertical, i18n ("Format"), this);
+    setMargin (5);
+    setSpacing (2);
+
+    format = new Q3ButtonGroup (3, Qt::Vertical, i18n ("Format"), this);
     new QRadioButton (i18n ("Same as source"), format);
     new QRadioButton (i18n ("Custom"), format);
     QWidget * customopts = new QWidget (format);
@@ -549,8 +567,7 @@ KDE_NO_CDTOR_EXPORT PrefMEncoderPage::PrefMEncoderPage (QWidget *parent, PartBas
     arguments = new QLineEdit ("", customopts);
     gridlayout->addWidget (argLabel, 0, 0);
     gridlayout->addWidget (arguments, 0, 1);
-    layout->addWidget (format);
-    layout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+    layout()->addItem(new QSpacerItem(0,0, QSizePolicy::Minimum, QSizePolicy::Expanding));
     connect (format, SIGNAL (clicked (int)), this, SLOT (formatClicked (int)));
 }
 
@@ -558,14 +575,9 @@ KDE_NO_EXPORT void PrefMEncoderPage::formatClicked (int id) {
     arguments->setEnabled (!!id);
 }
 
-KDE_NO_EXPORT void PrefMEncoderPage::record () {
-#if KDE_IS_VERSION(3,1,90)
+KDE_NO_EXPORT void PrefMEncoderPage::startRecording () {
     m_player->settings ()->recordcopy = !format->selectedId ();
-#else
-    m_player->settings ()->recordcopy = !format->id (format->selected ());
-#endif
     m_player->settings ()->mencoderarguments = arguments->text ();
-    RecorderPage::record ();
 }
 
 KDE_NO_EXPORT QString PrefMEncoderPage::name () {
@@ -581,26 +593,27 @@ KDE_NO_EXPORT QString PrefMPlayerDumpstreamPage::name () {
 }
 
 KDE_NO_CDTOR_EXPORT PrefFFMpegPage::PrefFFMpegPage (QWidget *parent, PartBase * player) : RecorderPage (parent, player) {
-    QVBoxLayout *layout = new QVBoxLayout (this, 5, 5);
+    setMargin (5);
+    setSpacing (2);
+
     QGridLayout *gridlayout = new QGridLayout (1, 2, 2);
     QLabel *argLabel = new QLabel (i18n("FFMpeg arguments:"), this);
     arguments = new QLineEdit ("", this);
     gridlayout->addWidget (argLabel, 0, 0);
     gridlayout->addWidget (arguments, 0, 1);
-    layout->addLayout (gridlayout);
-    layout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+    static_cast <QBoxLayout *>(layout())->addLayout (gridlayout);
+    layout()->addItem(new QSpacerItem(0,0, QSizePolicy::Minimum, QSizePolicy::Expanding));
 }
 
-KDE_NO_EXPORT void PrefFFMpegPage::record () {
+KDE_NO_EXPORT void PrefFFMpegPage::startRecording () {
     m_player->settings ()->ffmpegarguments = arguments->text ();
-    RecorderPage::record ();
 }
 
 KDE_NO_EXPORT QString PrefFFMpegPage::name () {
     return i18n ("&FFMpeg");
 }
 
-#ifdef HAVE_XINE
+#ifdef KMPLAYER_WITH_XINE
 KDE_NO_CDTOR_EXPORT PrefXinePage::PrefXinePage (QWidget *parent, PartBase * player) : RecorderPage (parent, player) {
     hide();
 }
@@ -611,45 +624,42 @@ KDE_NO_EXPORT QString PrefXinePage::name () {
 #endif
 
 KDE_NO_CDTOR_EXPORT PrefGeneralPageOutput::PrefGeneralPageOutput(QWidget *parent, OutputDriver * ad, OutputDriver * vd)
- : QFrame (parent) {
-    QGridLayout *layout = new QGridLayout (this, 2, 2, 5);
+ : KVBox (parent) {
+    setMargin (5);
+    setSpacing (2);
 
-    videoDriver = new QListBox (this);
+    videoDriver = new Q3ListBox (this);
     for (int i = 0; vd[i].driver; i++)
         videoDriver->insertItem (vd[i].description, i);
     QWhatsThis::add(videoDriver, i18n("Sets video driver. Recommended is XVideo, or, if it is not supported, X11, which is slower."));
-    layout->addWidget (new QLabel (i18n ("Video driver:"), this), 0, 0);
-    layout->addWidget (videoDriver, 1, 0);
 
-    audioDriver = new QListBox (this);
+    audioDriver = new Q3ListBox (this);
     for (int i = 0; ad[i].driver; i++)
         audioDriver->insertItem (ad[i].description, i);
-    layout->addWidget (new QLabel (i18n ("Audio driver:"), this), 0, 1);
-    layout->addWidget (audioDriver, 1, 1);
-    layout->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
+    layout()->addItem (new QSpacerItem (0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
 }
 
 KDE_NO_CDTOR_EXPORT PrefOPPageGeneral::PrefOPPageGeneral(QWidget *parent)
-: QFrame(parent)
+: KVBox(parent)
 {
     QVBoxLayout *layout = new QVBoxLayout (this, 5);
     layout->setAutoAdd (true);
 }
 
-KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : QFrame(parent)
+KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : KVBox(parent)
 {
-    QVBoxLayout *tabLayout = new QVBoxLayout (this, 5);
+    setMargin (5);
+    setSpacing (2);
+
     postProcessing = new QCheckBox (i18n ("Enable use of postprocessing filters"), this);
     postProcessing->setEnabled( true );
     disablePPauto = new QCheckBox (i18n ("Disable use of postprocessing when watching TV/DVD"), this);
 
-    tabLayout->addWidget( postProcessing );
-    tabLayout->addWidget( disablePPauto );
-    tabLayout->addItem ( new QSpacerItem( 5, 5, QSizePolicy::Minimum, QSizePolicy::Minimum ) );
+    layout()->addItem (new QSpacerItem(5, 5, QSizePolicy::Minimum, QSizePolicy::Minimum));
 
     PostprocessingOptions = new QTabWidget( this, "PostprocessingOptions" );
     PostprocessingOptions->setEnabled (true);
-    PostprocessingOptions->setAutoMask (false);
+    //PostprocessingOptions->setAutoMask (false);
     PostprocessingOptions->setTabPosition( QTabWidget::Top );
     PostprocessingOptions->setTabShape( QTabWidget::Rounded );
     PostprocessingOptions->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, PostprocessingOptions->sizePolicy().hasHeightForWidth() ) );
@@ -657,7 +667,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : QF
     QWidget *presetSelectionWidget = new QWidget( PostprocessingOptions, "presetSelectionWidget" );
     QGridLayout *presetSelectionWidgetLayout = new QGridLayout( presetSelectionWidget, 1, 1, 1);
 
-    QButtonGroup *presetSelection = new QButtonGroup(3, Qt::Vertical, presetSelectionWidget);
+    Q3ButtonGroup *presetSelection = new Q3ButtonGroup(3, Qt::Vertical, presetSelectionWidget);
     presetSelection->setInsideSpacing(KDialog::spacingHint());
 
     defaultPreset = new QRadioButton (i18n ("Default"), presetSelection);
@@ -681,7 +691,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : QF
     QWidget *customFiltersWidget = new QWidget( PostprocessingOptions, "customFiltersWidget" );
     QVBoxLayout *customFiltersWidgetLayout = new QVBoxLayout( customFiltersWidget );
 
-    QGroupBox *customFilters = new QGroupBox(0, Qt::Vertical, customFiltersWidget, "customFilters" );
+    Q3GroupBox *customFilters = new Q3GroupBox(0, Qt::Vertical, customFiltersWidget, "customFilters" );
     customFilters->setSizePolicy(QSizePolicy((QSizePolicy::SizeType)1, (QSizePolicy::SizeType)2));
     customFilters->setFlat(false);
     customFilters->setEnabled( false );
@@ -783,7 +793,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : QF
     //
     QWidget *deintSelectionWidget = new QWidget( PostprocessingOptions, "deintSelectionWidget" );
     QVBoxLayout *deintSelectionWidgetLayout = new QVBoxLayout( deintSelectionWidget);
-    QButtonGroup *deinterlacingGroup = new QButtonGroup(5, Qt::Vertical, deintSelectionWidget, "deinterlacingGroup" );
+    Q3ButtonGroup *deinterlacingGroup = new Q3ButtonGroup(5, Qt::Vertical, deintSelectionWidget, "deinterlacingGroup" );
 
     LinBlendDeinterlacer = new QCheckBox (i18n ("Linear blend deinterlacer"), deinterlacingGroup);
     LinIntDeinterlacer = new QCheckBox (i18n ("Linear interpolating deinterlacer"), deinterlacingGroup);
@@ -801,8 +811,6 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : QF
 
     PostprocessingOptions->insertTab( deintSelectionWidget, "" );
 
-    tabLayout->addWidget( PostprocessingOptions/*, 1, 0*/ );
-
     PostprocessingOptions->setEnabled(false);
     connect( customPreset, SIGNAL (toggled(bool) ), customFilters, SLOT(setEnabled(bool)));
     connect( postProcessing, SIGNAL( toggled(bool) ), PostprocessingOptions, SLOT( setEnabled(bool) ) );
@@ -820,28 +828,27 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(QWidget *parent) : QF
     QWhatsThis::add( customPreset, i18n( "Enable custom postprocessing filters (See: Custom preset -tab)" ) );
     QWhatsThis::add( fastPreset, i18n( "Enable mplayer's fast postprocessing filters" ) );
     PostprocessingOptions->changeTab( presetSelectionWidget, i18n( "General" ) );
-    customFilters->setTitle( QString::null );
+    customFilters->setTitle (QString ());
     QWhatsThis::add( HzDeblockAQuality, i18n( "Filter is used if there is enough CPU" ) );
     QWhatsThis::add( VtDeblockAQuality, i18n( "Filter is used if there is enough CPU" ) );
     QWhatsThis::add( DeringAQuality, i18n( "Filter is used if there is enough CPU" ) );
     //QWhatsThis::add( TmpNoiseSlider, i18n( "Strength of the noise reducer" ) );
     QWhatsThis::add( AutolevelsFullrange, i18n( "Stretches luminance to full range (0..255)" ) );
     PostprocessingOptions->changeTab( customFiltersWidget, i18n( "Custom Preset" ) );
-    deinterlacingGroup->setTitle( QString::null );
+    deinterlacingGroup->setTitle (QString ());
     PostprocessingOptions->changeTab( deintSelectionWidget, i18n( "Deinterlacing" ) );
     PostprocessingOptions->adjustSize();
 }
 
 KDE_NO_EXPORT void Preferences::confirmDefaults() {
-	// TODO: Switch to KMessageBox
-	switch( QMessageBox::warning( this, i18n("Reset Settings?"),
-        i18n("You are about to have all your settings overwritten with defaults.\nPlease confirm.\n"),
-        i18n("&OK"), i18n("&Cancel"), QString::null, 0, 1 ) ){
-    		case 0:	Preferences::setDefaults();
-        		break;
-    		case 1:	break;
-	}
-
+    // TODO: Switch to KMessageBox
+    switch( QMessageBox::warning( this, i18n("Reset Settings?"),
+                i18n("You are about to have all your settings overwritten with defaults.\nPlease confirm.\n"),
+                i18n ("&OK"), i18n ("&Cancel"), QString (), 0, 1)) {
+        case 0:	Preferences::setDefaults();
+                break;
+        case 1:	break;
+    }
 }
 
 KDE_NO_EXPORT void Preferences::setDefaults() {
